<?xml version="1.0" encoding="UTF-8"?>
<!--
<?xml-stylesheet type="text/xml" href="BillRegister.xsl"?>
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:doc="http://softmedica.pl/schema/CashRegister">
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
    <xsl:variable name="smallcase" select="'aąbcćdeęfghijklłmnńoópqrsśtuvwxyzżź'" />
    <xsl:variable name="uppercase" select="'AĄBCĆDEĘFGHIJKLŁMNŃOÓPQRSŚTUVWXYZŻŹ'" />
    <xsl:variable name="textSize">10px</xsl:variable>
    <xsl:variable name="headTextSize">10px</xsl:variable>
    <!-- =================================================================== -->
    <xsl:template match="/">
        <html>
            <head>
                <title>Zestawienie rachunków/faktur</title>
            </head>
            <body>
                <xsl:apply-templates select="doc:cashRegister" />
            </body>
        </html>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:cashRegister">
        <table border="0" rules="none" width="100%" style="font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};;">
            <xsl:apply-templates select="doc:header" />

            <tr>
                <td>
                    <xsl:if test="count(doc:company) > 0 or count(doc:bill) > 0 ">
                        <table border="1" rules="all" width="100%" cellpadding="2" cellspacing="0"
                               style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                            <colgroup>
                                <col width="5%"/>
                                <col/>
                                <col/>
                                <col/>
                                <col/>
                                <col/>
                                <col/>
                                <col/>
                            </colgroup>
                            
                            <xsl:if test="count(doc:company) > 0">
                                <xsl:apply-templates select="doc:company" />
                            </xsl:if>
                            <xsl:if test="count(doc:bill) > 0">
                                <tr style="text-align: center; background-color: #F3F3F3;">
                                    <td>Lp.</td>
                                    <td>Numer rachunku/fatury</td>
                                    <td>Odbiorca</td>
                                    <td>Kwota rachunku/fatury</td>
                                    <td>Data wystawienia</td>
                                    <td>Data płatności</td>
                                    <td>Forma płatności</td>
                                </tr>
                                <xsl:apply-templates select="doc:bill">
                                    <!--
                                    <xsl:sort select = "doc:issue_date" />
                                    <xsl:sort select = "doc:number" />
                                    <xsl:sort select = "doc:recipient" />
                                    -->
                                </xsl:apply-templates>
                                <tr>
                                    <td colspan="3" style="text-align: right; background-color: #F3F3F3">
                                        <div style="margin-right: 5px">
                                            Razem:
                                        </div>
                                    </td>
                                    <td style="text-align: right;">
                                        <div style="margin-right: 5px">
                                            <xsl:value-of select="translate(format-number(sum(doc:bill/doc:amount), '0.00'), '.', ',')" /> zł
                                        </div>
                                    </td>
                                    <td colspan="3" style="background-color: #F3F3F3"></td>
                                </tr>
                            </xsl:if>
                            <xsl:if test="count(doc:bill) = 0">
                                <tr style="text-align: center">
                                    <td colspan="7">
                                        <font style="color: #cc0000; font-size:12px;">
                                            Nie odnaleziono rachunków/faktur wystawionych w zadanym okresie.
                                        </font>
                                    </td>
                                </tr>
                            </xsl:if>

                        </table>
                    </xsl:if>
                    <xsl:if test="count(doc:company) = 0 and count(doc:bill) = 0 ">
                        <tr style="text-align: center">
                            <td>
                                <font style="color: #cc0000; font-size:12px;">
                                    Nie odnaleziono rachunków/faktur wystawionych w zadanym okresie.
                                </font>
                            </td>
                        </tr>
                    </xsl:if>
                    <tr>
                        <td>
                            <table border="0" rules="none" width="25%" align="right"
                                   style="font-family:Helvetica, Arial, sans-serif; font-size:{$textSize}; text-align: center;">
                                <tr>
                                    <td style="text-align: center; vertical-align: bottom; height: 3em; border-bottom: 1px solid #E3E3E3">
                                    &#160;
                                    </td>
                                </tr>
                                <tr>
                                    <td>
                                        Sporządził
                                    </td>
                                </tr>
                            </table>
                        </td>
                    </tr>
                </td>
            </tr>
            <xsl:call-template name="footer" />
        </table>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:header">
        <tr>
            <td>
                <table width="100%" border="0" rules="none">
                    <tr>
                        <td style="text-align:left" >
                            <table border="0" rules="none" style="font-family:Helvetica, Arial, sans-serif; font-size:{$headTextSize};">
                                <tr>
                                    <td style="text-align:center">
                                        <xsl:value-of select="doc:head1"/>
                                        <br/>
                                        <xsl:value-of select="doc:head2"/>
                                        <br/>
                                        <xsl:value-of select="doc:head3"/>
                                        <br/>
                                        <xsl:value-of select="doc:head4"/>
                                        <br/>
                                    </td>
                                </tr>
                            </table>
                        </td>
                        <td style="text-align:right">
                            <xsl:if test="doc:logo">
                                <xsl:variable name="logo">
                                    <xsl:value-of select="doc:logo" />
                                </xsl:variable>
                                <img src="{$logo}" alt=""/>
                            </xsl:if>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr>
            <td style="text-align:center; font-size: 13px; font-weight: bold">
                <p>
                    Zestawienie rachunków/faktur za okres od
                    <xsl:value-of select="doc:reportDateFrom" /> do
                    <xsl:value-of select="doc:reportDateTo" />
                </p>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:company">
        <tr style="background-color : #E6FFE6; text-align : center;">
            <td colspan="7">
                <xsl:value-of select="doc:name" />
                <br/>
                <xsl:value-of select="doc:adress" />
                <xsl:if test="count(doc:nip) > 0 or count(doc:regon) > 0">
                    <br/>
                    <xsl:if test="count(doc:nip) > 0">
                        NIP:&#160;
                        <xsl:value-of select="doc:nip" />
                        &#160;
                    </xsl:if>
                    <xsl:if test="count(doc:regon) > 0">
                        REGON:&#160;
                        <xsl:value-of select="doc:regon" />
                    </xsl:if>
                </xsl:if>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:bill">
        <tr style="text-align : center;">
            <td>
                <xsl:number value="position()" format="1." />
            </td>
            <td>
                <xsl:value-of select="doc:number" />
            </td>
            <td style="text-align: left;">
                <xsl:value-of select="doc:recipient" />
            </td>
            <td style="text-align: right;">
                <div style="margin-right: 5px">
                    <xsl:value-of select="translate(doc:amount, '.', ',')" /> zł
                </div>
            </td>
            <td>
                <xsl:value-of select="doc:issue_date" />
            </td>
            <td>
                <xsl:value-of select="doc:pay_date" />
            </td>
            <td>
                <xsl:value-of select="doc:pay_form" />
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="footer">
        <tr>
            <td style="text-align: center;">
                <br/>
                Raport wygenerowany przy pomocy
            </td>
        </tr>
        <tr>
            <td  style="text-align: center;">
                <a href="http://www.softmedica.pl" target="_blank">
                    <img border="0" width="120" height="18" alt="SoftMedica Medycyna Pracy" title="SoftMedica Medycyna Pracy" src="http://www.softmedica.pl/SoftMedica120x18.png"/>
                </a>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
</xsl:stylesheet>