<?xml version="1.0" encoding="UTF-8"?>
<!--
<?xml-stylesheet type="text/xml" href="CompaniesWithExecutedExaminations.xsl"?>
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:doc="http://softmedica.pl/schema/CompaniesWithExecutedExaminations">
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
    <xsl:variable name="smallcase" select="'aąbcćdeęfghijklłmnńoópqrsśtuvwxyzżź'" />
    <xsl:variable name="uppercase" select="'AĄBCĆDEĘFGHIJKLŁMNŃOÓPQRSŚTUVWXYZŻŹ'" />
    <xsl:variable name="textSize">10px</xsl:variable>
    <xsl:variable name="headTextSize">10px</xsl:variable>
    <!-- =================================================================== -->
    <xsl:template match="/">
        <html>
            <head>
                <title>Lista przedsiębiorstw</title>
            </head>
            <body>
                <xsl:apply-templates select="doc:companiesWithExecutedExaminations" />
            </body>
        </html>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:companiesWithExecutedExaminations">
        <table border="0" rules="none" width="100%" style="font-family:Helvetica, Arial, sans-serif; font-size:11px;">
            <xsl:apply-templates select="doc:header" />
            
            <xsl:if test="count(doc:company) = 0">
                <tr style="text-align: center">
                    <td>
                        <font style="color: #cc0000; font-size:12px;">
                                Nie odnaleziono badań wykonanych w zadanym okresie.
                        </font>
                    </td>
                </tr>
            </xsl:if>

            <xsl:apply-templates select="doc:company" >
                <xsl:sort select = "doc:name" />
            </xsl:apply-templates>
            
            <xsl:call-template name="footer" />
        </table>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:header">
        <tr>
            <td>
                <table width="100%" border="0" rules="none">
                    <tr>
                        <td style="text-align:left" >
                            <table border="0" rules="none" style="font-family:Helvetica, Arial, sans-serif; font-size:{$headTextSize};">
                                <tr>
                                    <td style="text-align:center">
                                        <xsl:value-of select="doc:head1"/>
                                        <br/>
                                        <xsl:value-of select="doc:head2"/>
                                        <br/>
                                        <xsl:value-of select="doc:head3"/>
                                        <br/>
                                        <xsl:value-of select="doc:head4"/>
                                        <br/>
                                    </td>
                                </tr>
                            </table>
                        </td>
                        <td style="text-align:right">
                            <xsl:if test="doc:logo">
                                <xsl:variable name="logo">
                                    <xsl:value-of select="doc:logo" />
                                </xsl:variable>
                                <img src="{$logo}" alt=""/>
                            </xsl:if>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr>
            <td style="text-align:center; font-size: 13px; font-weight: bold">
                <p>
                    Lista przedsiębiorstw którym wykonano badania w okresie
                    <br/>od
                    <xsl:value-of select="doc:reportDateFrom" /> do
                    <xsl:value-of select="doc:reportDateTo" />
                </p>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:company">
        <tr>
            <td>
                <table border="1" rules="all" width="100%" cellpadding="2" cellspacing="0"
                            style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                    <colgroup>
                        <col width="5%"/>
                        <col width="70%"/>
                        <col/>
                    </colgroup>
                    <tr style="background-color : #E6FFE6; text-align : center;">
                        <td>
                            <xsl:number value="position()" format="1." />
                        </td>
                        <td colspan="2">
                            <xsl:value-of select="doc:name" />
                            <br/>
                            <xsl:value-of select="doc:adress" />
                            <xsl:if test="count(doc:nip) > 0 or count(doc:regon) > 0">
                                <br/>
                                <xsl:if test="count(doc:nip) > 0">
                                    NIP:&#160;
                                    <xsl:value-of select="doc:nip" />
                                    &#160;
                                </xsl:if>
                                <xsl:if test="count(doc:regon) > 0">
                                    REGON:&#160;
                                    <xsl:value-of select="doc:regon" />
                                </xsl:if>
                            </xsl:if>
                        </td>
                    </tr>

                    <xsl:if test="count(doc:examination) = 0">
                        <tr style="text-align: center">
                            <td colspan="3">
                                <font style="color: #cc0000">
                                    Nie odnaleziono badań wykonanych w zadanym okresie.
                                </font>
                            </td>
                        </tr>
                    </xsl:if>
        
                    <xsl:if test="count(doc:examination) > 0">
                        <tr style="text-align: center; background-color: #F3F3F3;">
                            <td colspan="2">Typ badania</td>
                            <td>Liczba badań</td>
                        </tr>
                        <xsl:apply-templates select="doc:examination[doc:type != 'Badanie do celów sanitarno-epidemiologicznych']" >
                            <xsl:sort select = "doc:type" />
                        </xsl:apply-templates>

                        <xsl:apply-templates select="doc:examination[doc:type = 'Badanie do celów sanitarno-epidemiologicznych']" >
                            <xsl:sort select = "doc:type" />
                        </xsl:apply-templates>

                        <tr style="text-align: center; color: navy">
                            <td colspan="2">Razem badań profilaktycznych</td>
                            <td>
                                <xsl:value-of select="sum(doc:examination/doc:count[../doc:type != 'Badanie do celów sanitarno-epidemiologicznych'])"/>
                            </td>
                        </tr>
           
                        <tr style="text-align: center; color: #cc0000">
                            <td colspan="2">Razem</td>
                            <td>
                                <xsl:value-of select="sum(doc:examination/doc:count)"/>
                            </td>
                        </tr>
                    </xsl:if>
                </table>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:examination">
        <tr style="text-align: center">
            <td colspan="2">
                <xsl:value-of select="doc:type" />
            </td>
            <td>
                <xsl:value-of select="doc:count" />
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="footer">
        <tr>
            <td style="text-align: center;">
                <br/>
                    Raport wygenerowany przy pomocy
            </td>
        </tr>
        <tr>
            <td  style="text-align: center;">
                <a href="http://www.softmedica.pl" target="_blank">
                    <img border="0" width="120" height="18" alt="SoftMedica Medycyna Pracy" title="SoftMedica Medycyna Pracy" src="http://www.softmedica.pl/SoftMedica120x18.png"/>
                </a>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
</xsl:stylesheet>