<?xml version="1.0" encoding="UTF-8"?>
<!--
<?xml-stylesheet type="text/xml" href="DailyReport.xsl"?>
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:doc="http://softmedica.pl/schema/DailyReport">
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
    <xsl:variable name="smallcase" select="'aąbcćdeęfghijklłmnńoópqrsśtuvwxyzżź'" />
    <xsl:variable name="uppercase" select="'AĄBCĆDEĘFGHIJKLŁMNŃOÓPQRSŚTUVWXYZŻŹ'" />
    <xsl:variable name="textSize">10px</xsl:variable>
    <xsl:variable name="headTextSize">10px</xsl:variable>
    <!-- =================================================================== -->
    <xsl:template match="/">
        <html>
            <head>
                <title>Zestawienie świadczeń medycznych</title>

                <script type="text/javascript">
                    //<![CDATA[

                /**
                 *
                 *  Sortable HTML table
                 *  http://www.webtoolkit.info/
                 *
                 **/

                function SortableTable (tableEl, offset) {

                    //offset - jeśli 1 nie jest sortowana pierwsza kolumna

                    this.tbody = tableEl.getElementsByTagName('tbody');
                    this.thead = tableEl.getElementsByTagName('thead');
                    this.tfoot = tableEl.getElementsByTagName('tfoot');

                    this.getInnerText = function (el) {
                        if (typeof(el.textContent) != 'undefined') return el.textContent;
                        if (typeof(el.innerText) != 'undefined') return el.innerText;
                        if (typeof(el.innerHTML) == 'string') return el.innerHTML.replace(/<[^<>]+>/g,'');
                    }

                    this.getParent = function (el, pTagName) {
                        if (el == null) return null;
                        else if (el.nodeType == 1 && el.tagName.toLowerCase() == pTagName.toLowerCase())
                            return el;
                        else
                            return this.getParent(el.parentNode, pTagName);
                    }

                    this.sort = function (cell) {

                        var column = cell.cellIndex;
                        var itm = this.getInnerText(this.tbody[0].rows[1].cells[column]);
                        var sortfn = this.sortCaseInsensitive;

                        if (itm.match(/\d\d[-]+\d\d[-]+\d\d\d\d/)) sortfn = this.sortDate; // date format mm-dd-yyyy
                        if (itm.replace(/^\s+|\s+$/g,"").match(/^[\d\.]+$/)) sortfn = this.sortNumeric;

                        this.sortColumnIndex = column;

                        var newRows = new Array();
                        for (j = 0; j < this.tbody[0].rows.length; j++) {
                            newRows[j] = this.tbody[0].rows[j];
                        }

                        newRows.sort(sortfn);

                        if (cell.getAttribute("sortdir") == 'down') {
                            newRows.reverse();
                            cell.setAttribute('sortdir','up');
                        } else {
                            cell.setAttribute('sortdir','down');
                        }

                        for (i=0;i<newRows.length;i++) {
                            this.tbody[0].appendChild(newRows[i]);
                        }

                    }

                    this.sortCaseInsensitive = function(a,b) {
                        aa = thisObject.getInnerText(a.cells[thisObject.sortColumnIndex]).toLowerCase();
                        bb = thisObject.getInnerText(b.cells[thisObject.sortColumnIndex]).toLowerCase();
                        if (aa==bb) return 0;
                        if (aa<bb) return -1;
                        return 1;
                    }

                    this.sortDate = function(a,b) {
                        aa = thisObject.getInnerText(a.cells[thisObject.sortColumnIndex]);
                        bb = thisObject.getInnerText(b.cells[thisObject.sortColumnIndex]);
                        date1 = aa.substr(6,4)+aa.substr(3,2)+aa.substr(0,2);
                        date2 = bb.substr(6,4)+bb.substr(3,2)+bb.substr(0,2);
                        if (date1==date2) return 0;
                        if (date1<date2) return -1;
                        return 1;
                    }

                    this.sortNumeric = function(a,b) {
                        aa = parseFloat(thisObject.getInnerText(a.cells[thisObject.sortColumnIndex]));
                        if (isNaN(aa)) aa = 0;
                        bb = parseFloat(thisObject.getInnerText(b.cells[thisObject.sortColumnIndex]));
                        if (isNaN(bb)) bb = 0;
                        return aa-bb;
                    }

                    // define variables
                    var thisObject = this;
                    var sortSection = this.thead;

                    // constructor actions
                    if (!(this.tbody && this.tbody[0].rows && this.tbody[0].rows.length > 0)) return;

                    if (sortSection && sortSection[0].rows && sortSection[0].rows.length > 0) {
                        var sortRow = sortSection[0].rows[0];
                    } else {
                        return;
                    }


                    for (var i=offset; i<sortRow.cells.length; i++) {
                        sortRow.cells[i].sTable = this;
                        sortRow.cells[i].onclick = function () {
                            this.sTable.sort(this);
                            setRowNumber(tableEl);
                            return false;
                        }
                    }
                }

                function setRowNumber(tableEl) {
                    var tbody = tableEl.getElementsByTagName('tbody');
                    for(rowNo=0; rowNo < tbody[0].rows.length ; rowNo++) {
                        var cell = tbody[0].rows[rowNo].cells[0] ;
                        var rowNoText = rowNo+1;
                        cell.innerHTML = rowNoText + ".";
                        cell.innerText = rowNoText + ".";
                    }
                }
                //]]>
                </script>
            </head>
            <body>
                <xsl:apply-templates select="doc:daily_report" />
            </body>
        </html>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:daily_report">
        <table border="0" rules="none" width="100%" style="font-family:Helvetica, Arial, sans-serif; font-size:11px;">
            <xsl:apply-templates select="doc:header" />

            <xsl:if test="count(doc:daily_report_item) = 0">
                <tr style="text-align: center">
                    <td>
                        <font style="color: #cc0000; font-size:12px;">
                            Nie odnaleziono badań wykonanych w zadanym okresie.
                        </font>
                    </td>
                </tr>
            </xsl:if>

            <xsl:if test="count(doc:daily_report_item) > 0">
                <tr>
                    <td>
                        <table id="sortable_table" border="1" rules="all" width="100%" cellpadding="2" cellspacing="0"
                               style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                            <thead>
                                <tr style="text-align: center; background-color: #F3F3F3;">
                                    <td style="text-align: center;">
                                        Lp.
                                    </td>
                                    <td  style="text-align: center;">
                                        Nazwisko
                                    </td>
                                    <td  style="text-align: center;">
                                        Imię
                                    </td>
                                    <td  style="text-align: center;">
                                        PESEL
                                    </td>
                                    <td  style="text-align: center;">
                                        Adres
                                    </td>
                                    <td  style="text-align: center;">
                                        Typ badania
                                    </td>
                                    <td  style="text-align: center;">
                                        Kod świadczenia
                                    </td>
                                    <xsl:if test="doc:header/doc:reportDateFrom != doc:header/doc:reportDateTo">
                                        <td  style="text-align: center;">
                                            Data badania
                                        </td>
                                    </xsl:if>
                                    <td  style="text-align: center;">
                                        Przedsiębiorstwo
                                    </td>
                                    <td  style="text-align: center;">
                                        Nr umowy
                                    </td>
                                    <td  style="text-align: center;">
                                        Nr przepustki
                                    </td>
                                    <td  style="text-align: center;">
                                        Wykonawca świadczenia
                                    </td>
                                    <td  style="text-align: center;">
                                        Lekarz zlecający
                                    </td>
                                </tr>
                            </thead>
                            <tbody>
                                <xsl:apply-templates select="doc:daily_report_item" >
                                    <xsl:sort select = "doc:employee_surname" />
                                    <xsl:sort select = "doc:employee_name" />
                                    <xsl:sort select = "doc:examination_date" />
                                </xsl:apply-templates>
                            </tbody>
                        </table>

                        <script type="text/javascript">
                            var t = new SortableTable(document.getElementById('sortable_table'), 1);
                        </script>
                    </td>
                </tr>
            </xsl:if>

            <xsl:call-template name="footer" />
        </table>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:header">
        <tr>
            <td>
                <table width="100%" border="0" rules="none">
                    <tr>
                        <td style="text-align:left" >
                            <table border="0" rules="none" style="font-family:Helvetica, Arial, sans-serif; font-size:{$headTextSize};">
                                <tr>
                                    <td style="text-align:center">
                                        <xsl:value-of select="doc:head1"/>
                                        <br/>
                                        <xsl:value-of select="doc:head2"/>
                                        <br/>
                                        <xsl:value-of select="doc:head3"/>
                                        <br/>
                                        <xsl:value-of select="doc:head4"/>
                                        <br/>
                                    </td>
                                </tr>
                            </table>
                        </td>
                        <td style="text-align:right">
                            <xsl:if test="doc:logo">
                                <xsl:variable name="logo">
                                    <xsl:value-of select="doc:logo" />
                                </xsl:variable>
                                <img src="{$logo}" alt=""/>
                            </xsl:if>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr>
            <td style="text-align:center; font-size: 13px; font-weight: bold">
                <p>
                    Zestawienie świadczeń medycznych
                    <xsl:if test="doc:reportDateFrom != doc:reportDateTo">
                        w okresie
                        <br/>od
                        <xsl:value-of select="doc:reportDateFrom" /> do
                        <xsl:value-of select="doc:reportDateTo" />
                    </xsl:if>
                    <xsl:if test="doc:reportDateFrom = doc:reportDateTo">
                        w dniu
                        <xsl:value-of select="doc:reportDateFrom" />
                    </xsl:if>
                </p>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:daily_report_item">
        <tr style="text-align: left">
            <td style="text-align: center;">
                <xsl:number value="position()" format="1." />
            </td>
            <td>
                <xsl:value-of select="translate(doc:employee_surname, $smallcase, $uppercase)" />
            </td>
            <td>
                <xsl:value-of select="translate(doc:employee_name, $smallcase, $uppercase)" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="doc:employee_pesel" />
            </td>
            <td>
                <xsl:value-of select="doc:employee_address" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="doc:examination_type" />
            </td>
            <td>
                <xsl:value-of select="doc:examination_code" />
            </td>
            <xsl:if test="../doc:header/doc:reportDateFrom != ../doc:header/doc:reportDateTo">
                <td style="text-align: center">
                    <xsl:value-of select="doc:examination_date" />
                </td>
            </xsl:if>
            <td>
                <xsl:if test="not(doc:quasi_company)">
                    <xsl:value-of select="doc:company" />
                </xsl:if>
                <xsl:if test="doc:quasi_company">
                    <xsl:value-of select="doc:quasi_company" />
                </xsl:if>

            </td>
            <td style="text-align: center">
                <xsl:value-of select="doc:contract_no" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="doc:pass_no" />
            </td>
            <td>
                <xsl:value-of select="doc:performing" />
            </td>
            <td>
                <xsl:value-of select="doc:ordering" />
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="footer">
        <tr>
            <td style="text-align: center;">
                <br/>
                Raport wygenerowany przy pomocy
            </td>
        </tr>
        <tr>
            <td  style="text-align: center;">
                <a href="http://www.softmedica.pl" target="_blank">
                    <img border="0" width="120" height="18" alt="SoftMedica Medycyna Pracy" title="SoftMedica Medycyna Pracy" src="http://www.softmedica.pl/SoftMedica120x18.png"/>
                </a>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
</xsl:stylesheet>