<?xml version="1.0" encoding="UTF-8"?>
<!--
<?xml-stylesheet type="text/xml" href="Deciders.xsl"?>
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:doc="http://softmedica.pl/schema/Deciders">
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
    <xsl:variable name="smallcase" select="'aąbcćdeęfghijklłmnńoópqrsśtuvwxyzżź'" />
    <xsl:variable name="uppercase" select="'AĄBCĆDEĘFGHIJKLŁMNŃOÓPQRSŚTUVWXYZŻŹ'" />
    <xsl:variable name="textSize">10px</xsl:variable>
    <xsl:variable name="headTextSize">10px</xsl:variable>
    <!-- =================================================================== -->
    <xsl:template match="/">
        <html>
            <head>
                <title>Orzecznicy</title>
            </head>
            <body>
                <xsl:apply-templates select="doc:deciders" />
            </body>
        </html>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:deciders">
        <table border="0" rules="none" width="100%" style="font-family:Helvetica, Arial, sans-serif; font-size:11px;">
            <xsl:apply-templates select="doc:header" />

            <xsl:if test="count(doc:decider) = 0">
                <tr style="text-align: center">
                    <td>
                        <font style="color: #cc0000; font-size:12px;">
                            Nie odnaleziono orzeczonych badań wykonanych w zadanym okresie.
                        </font>
                    </td>
                </tr>
            </xsl:if>

            <xsl:if test="count(doc:decider) > 0">
                <tr>
                    <td>
                        <table border="1" rules="all" width="100%" cellpadding="2" cellspacing="0"
                               style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                            <colgroup>
                                <col width="5%"/>
                                <col width="35%"/>
                                <col width="15%"/>
                                <col width="15%"/>
                                <col width="15%"/>
                                <col/>
                            </colgroup>
                            <tr style="text-align: center; background-color: #F3F3F3;">
                                <td style="text-align: center;">
                                    Nr
                                </td>
                                <td  style="text-align: center;">
                                    Orzecznik
                                </td>
                                <td  style="text-align: center;">
                                    Numer Prawa
                                </td>
                                <td  style="text-align: center;">
                                    Badanie profilaktyczne
                                </td>
                                <td  style="text-align: center;">
                                    Badanie profilaktyczne kierowcy transportu
                                </td>
                                <td  style="text-align: center;">
                                    Badanie do celów sanitarno-epidemiologicznych
                                </td>
                            </tr>
                            <xsl:apply-templates select="doc:decider" >
                                <xsl:sort select = "doc:name" />
                            </xsl:apply-templates>
                        </table>
                    </td>
                </tr>
            </xsl:if>

            <xsl:call-template name="footer" />
        </table>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:header">
        <tr>
            <td>
                <table width="100%" border="0" rules="none">
                    <tr>
                        <td style="text-align:left" >
                            <table border="0" rules="none" style="font-family:Helvetica, Arial, sans-serif; font-size:{$headTextSize};">
                                <tr>
                                    <td style="text-align:center">
                                        <xsl:value-of select="doc:head1"/>
                                        <br/>
                                        <xsl:value-of select="doc:head2"/>
                                        <br/>
                                        <xsl:value-of select="doc:head3"/>
                                        <br/>
                                        <xsl:value-of select="doc:head4"/>
                                        <br/>
                                    </td>
                                </tr>
                            </table>
                        </td>
                        <td style="text-align:right">
                            <xsl:if test="doc:logo">
                                <xsl:variable name="logo">
                                    <xsl:value-of select="doc:logo" />
                                </xsl:variable>
                                <img src="{$logo}" alt=""/>
                            </xsl:if>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr>
            <td style="text-align:center; font-size: 13px; font-weight: bold">
                <p>
                    Orzecznicy i orzeczone badania w okresie
                    <br/>od
                    <xsl:value-of select="doc:reportDateFrom" /> do
                    <xsl:value-of select="doc:reportDateTo" />
                </p>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:decider">
        <tr style="text-align: center">
            <td style="text-align: center;">
                <xsl:number value="position()" format="1." />
            </td>
            <td>
                <xsl:value-of select="translate(doc:name, $smallcase, $uppercase)" />
            </td>
            <td>
                <xsl:value-of select="doc:rights" />
            </td>
            <td>
                <xsl:apply-templates select="doc:examination_group">
                    <xsl:with-param name="type" select="'Badanie profilaktyczne'"/>
                </xsl:apply-templates>
            </td>
            <td>
                <xsl:apply-templates select="doc:examination_group">
                    <xsl:with-param name="type" select="'Badanie profilaktyczne kierowcy transportu'"/>
                </xsl:apply-templates>
            </td>
            <td>
                <xsl:apply-templates select="doc:examination_group">
                    <xsl:with-param name="type" select="'Badanie do celów sanitarno-epidemiologicznych'"/>
                </xsl:apply-templates>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:examination_group">
        <xsl:param name="type" />
        <xsl:if test="$type = doc:type">
            <xsl:value-of select="doc:count" />
        </xsl:if>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="footer">
        <tr>
            <td style="text-align: center;">
                <br/>
                Raport wygenerowany przy pomocy
            </td>
        </tr>
        <tr>
            <td  style="text-align: center;">
                <a href="http://www.softmedica.pl" target="_blank">
                    <img border="0" width="120" height="18" alt="SoftMedica Medycyna Pracy" title="SoftMedica Medycyna Pracy" src="http://www.softmedica.pl/SoftMedica120x18.png"/>
                </a>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
</xsl:stylesheet>