<?xml version="1.0" encoding="UTF-8"?>
<!--
<?xml-stylesheet type="text/xml" href="Disabilities.xsl"?>
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:doc="http://softmedica.pl/schema/Disabilities">
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
    <xsl:variable name="smallcase" select="'aąbcćdeęfghijklłmnńoópqrsśtuvwxyzżź'" />
    <xsl:variable name="uppercase" select="'AĄBCĆDEĘFGHIJKLŁMNŃOÓPQRSŚTUVWXYZŻŹ'" />
    <xsl:variable name="textSize">10px</xsl:variable>
    <xsl:variable name="headTextSize">10px</xsl:variable>
    <!-- =================================================================== -->
    <xsl:template match="/">
        <html>
            <head>
                <title>Orzeczenia o niepełnosprawności</title>
            </head>
            <body>
                <xsl:apply-templates select="doc:disabilities" />
            </body>
        </html>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:disabilities">
        <table border="0" rules="none" width="100%" style="font-family:Helvetica, Arial, sans-serif; font-size:11px;">
            <xsl:apply-templates select="doc:header" />
            <xsl:if test="count(doc:company) = 0">
                <tr style="text-align: center">
                    <td>
                        <font style="color: #cc0000; font-size:12px;">
                            Nie odnaleziono orzeczeń o niepełnosprawności wygasających w zadanym okresie.
                        </font>
                    </td>
                </tr>
            </xsl:if>

            <xsl:apply-templates select="doc:company" >
                <xsl:sort select = "doc:name" />
            </xsl:apply-templates>

            <xsl:call-template name="footer" />
        </table>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:header">
        <tr>
            <td>
                <table width="100%" border="0" rules="none">
                    <tr>
                        <td style="text-align:left" >
                            <table border="0" rules="none" style="font-family:Helvetica, Arial, sans-serif; font-size:{$headTextSize};">
                                <tr>
                                    <td style="text-align:center">
                                        <xsl:value-of select="doc:head1"/>
                                        <br/>
                                        <xsl:value-of select="doc:head2"/>
                                        <br/>
                                        <xsl:value-of select="doc:head3"/>
                                        <br/>
                                        <xsl:value-of select="doc:head4"/>
                                        <br/>
                                    </td>
                                </tr>
                            </table>
                        </td>
                        <td style="text-align:right">
                            <xsl:if test="doc:logo">
                                <xsl:variable name="logo">
                                    <xsl:value-of select="doc:logo" />
                                </xsl:variable>
                                <img src="{$logo}" alt=""/>
                            </xsl:if>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr>
            <td style="text-align:center; font-size: 13px; font-weight: bold">
                <p>
                    Orzeczenia o niepełnosprawności wygasające w okresie od
                    <xsl:value-of select="doc:reportDateFrom" /> do
                    <xsl:value-of select="doc:reportDateTo" />
                </p>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:company">
        <tr>
            <td>
                <table border="1" rules="all" width="100%" cellpadding="2" cellspacing="0"
                       style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                    <colgroup>
                        <col width="5%"/>
                        <col width="35%"/>
                        <col width="20%"/>
                        <col width="20%"/>
                        <col width="20%"/>
                    </colgroup>
                    <tr style="background-color : #E6FFE6; text-align : center;">
                        <td>
                            <xsl:number value="position()" format="1." />
                        </td>
                        <td colspan="4">
                            <xsl:value-of select="doc:name" />
                            <br/>
                            <xsl:value-of select="doc:adress" />
                            <xsl:if test="count(doc:nip) > 0 or count(doc:regon) > 0">
                                <br/>
                                <xsl:if test="count(doc:nip) > 0">
                                    NIP:&#160;
                                    <xsl:value-of select="doc:nip" />
                                    &#160;
                                </xsl:if>
                                <xsl:if test="count(doc:regon) > 0">
                                    REGON:&#160;
                                    <xsl:value-of select="doc:regon" />
                                </xsl:if>
                            </xsl:if>
                        </td>
                    </tr>
                    <xsl:if test="count(doc:employee) = 0">
                        <tr style="text-align: center">
                            <td colspan="5">
                                <font style="color: #cc0000">
                                    Nie odnaleziono orzeczeń wygasających w zadanym okresie.
                                </font>
                            </td>
                        </tr>
                    </xsl:if>
                    <xsl:apply-templates select="doc:employee" >
                        <xsl:with-param name="company_number" >
                            <xsl:number value="position()" format="1." />
                        </xsl:with-param>
                        <xsl:sort select = "doc:surname" />
                        <xsl:sort select = "doc:name" />
                    </xsl:apply-templates>
                </table>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:employee">
        <xsl:param name="company_number" />
        <tr style="background-color: #fffad5; text-align: center;">
            <td style="text-align: center;">
                <xsl:number value="$company_number" format="1." />
                <xsl:number value="position()" format="1." />
            </td>
            <td colspan="3" style="text-align: left;">
                Nazwisko i imię:
                <xsl:value-of select="translate(doc:surname, $smallcase, $uppercase)" />&#160;
                <xsl:value-of select="translate(doc:name, $smallcase, $uppercase)" />
            </td>
            <td>
                PESEL:
                <xsl:value-of select="doc:pesel" />
            </td>
        </tr>
        <xsl:apply-templates select="doc:disability">
            <xsl:sort select = "doc:decision/doc:decision_start_date" />
            <xsl:with-param name="employee_number" >
                <xsl:number value="$company_number" format="1." />
                <xsl:number value="position()" format="1." />
            </xsl:with-param>
        </xsl:apply-templates>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:disability">
        <xsl:param name="employee_number" />
        <tr style="text-align: center; background-color: #F3F3F3;">
            <xsl:if test="count(doc:decision) > 0">
                <xsl:if test="count(doc:decision) = 0">
                    <td rowspan="2" style="text-align: center; background-color: #F3F3F3;">
                        <xsl:value-of select="$employee_number" />
                        <xsl:number value="position()" format="1." />
                    </td>
                </xsl:if>
                <xsl:if test="count(doc:decision) = 1">
                    <td rowspan="4" style="text-align: center; background-color: #F3F3F3;">
                        <xsl:value-of select="$employee_number" />
                        <xsl:number value="position()" format="1." />
                    </td>
                </xsl:if>
                <xsl:if test="count(doc:decision) = 2">
                    <td rowspan="5" style="text-align: center; background-color: #F3F3F3;">
                        <xsl:value-of select="$employee_number" />
                        <xsl:number value="position()" format="1." />
                    </td>
                </xsl:if>
            </xsl:if>
            <td colspan="2">
                Przyczyna niepełnosprawności
            </td>
            <td>
                Data zatrudnienia
            </td>
            <td>
                Emeryt
            </td>
        </tr>
        <tr style="text-align: center">
            <td colspan="2">
                <xsl:value-of select="doc:cause_of_disability" />
            </td>
            <td>
                <xsl:value-of select="doc:employment_date" />
            </td>
            <td>
                <xsl:if test="not(doc:retiree)">
                    NIE
                </xsl:if>
                <xsl:value-of select="doc:retiree" />

            </td>
        </tr>
        <xsl:if test="count(doc:decision) > 0">
            <tr style="text-align: center; background-color: #F3F3F3;">
                <td>
                    Organ wydający orzeczenie o niepełnosprawności
                </td>
                <td>
                    Stopień niepełnosprawności
                </td>
                <td>
                    Data wystawienia orzeczenia
                </td>
                <td>
                    Data zakończenia obowiązywania orzeczenia
                </td>
            </tr>
        </xsl:if>
        <xsl:apply-templates select="doc:decision">
            <xsl:sort select = "@decider" order="descending"/>
            <xsl:sort select = "doc:decision_start_date" />
        </xsl:apply-templates>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:decision">
        <tr style="text-align: center">
            <td>
                <xsl:value-of select="@decider" />
            </td>
            <td>
                <xsl:value-of select="doc:disability_level" />
            </td>
            <td>
                <xsl:value-of select="doc:decision_start_date" />
            </td>
            <td>
                <font style="color: #cc0000">
                    <xsl:value-of select="doc:decision_stop_date" />
                </font>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="footer">
        <tr>
            <td style="text-align: center;">
                <br/>
                Raport wygenerowany przy pomocy
            </td>
        </tr>
        <tr>
            <td  style="text-align: center;">
                <a href="http://www.softmedica.pl" target="_blank">
                    <img border="0" width="120" height="18" alt="SoftMedica Medycyna Pracy" title="SoftMedica Medycyna Pracy" src="http://www.softmedica.pl/SoftMedica120x18.png"/>
                </a>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
</xsl:stylesheet>