<?xml version="1.0" encoding="UTF-8"?>
<!--
<?xml-stylesheet type="text/xml" href="ExaminationsAndConsultations.xsl"?>
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:doc="http://softmedica.pl/schema/ExaminationsAndConsultations">
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
    <xsl:variable name="smallcase" select="'aąbcćdeęfghijklłmnńoópqrsśtuvwxyzżź'" />
    <xsl:variable name="uppercase" select="'AĄBCĆDEĘFGHIJKLŁMNŃOÓPQRSŚTUVWXYZŻŹ'" />
    <xsl:variable name="textSize">10px</xsl:variable>
    <xsl:variable name="headTextSize">10px</xsl:variable>
    <!-- =================================================================== -->
    <xsl:template match="/">
        <html>
            <head>
                <title>
                    <xsl:choose>
                        <xsl:when test="/doc:examinationsAndConsultations/@contentType = 'examinations'">
                            Badania pomocnicze
                        </xsl:when>
                        <xsl:otherwise>
                            Konsultacje specjalistyczne
                        </xsl:otherwise>
                    </xsl:choose>
                </title>
            </head>
            <body>
                <xsl:apply-templates select="doc:examinationsAndConsultations" />
            </body>
        </html>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:examinationsAndConsultations">
        <table border="0" rules="none" width="100%" style="font-family:Helvetica, Arial, sans-serif; font-size:11px;">
            <xsl:apply-templates select="doc:header" />

            <xsl:if test="count(doc:summaryExamination) = 0 and count(doc:company) = 0">
                <tr>
                    <td style="text-align: center;">
                        <font style="color: #cc0000; font-size:12px;">
                            <xsl:choose>
                                <xsl:when test="/doc:examinationsAndConsultations/@contentType = 'examinations'">
                                    Nie odnaleziono badań pomocniczych w zadanym okresie.
                                </xsl:when>
                                <xsl:otherwise>
                                    Nie odnaleziono konsultacji specjalistycznych w zadanym okresie.
                                </xsl:otherwise>
                            </xsl:choose>
                        </font>
                    </td>
                </tr>
            </xsl:if>

            <xsl:if test="count(doc:summaryExamination) > 0">
                <tr>
                    <td>
                        <table border="1" rules="all" width="100%" cellpadding="1" cellspacing="0"
                               style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                            <colgroup>
                                <col width="5%"/>
                                <col width="28%"/>
                                <col width="33%"/>
                                <col/>
                            </colgroup>

                            <tr style="text-align: center; background-color: #F3F3F3;">
                                <td>
                                    Lp.
                                </td>
                                <td colspan="2" >
                                    Nazwa badania
                                </td>
                                <td>
                                    Liczba wykonanych badań
                                </td>
                            </tr>

                            <xsl:apply-templates select="doc:summaryExamination" >
                                <xsl:sort select = "doc:description" />
                            </xsl:apply-templates>

                        </table>
                    </td>
                </tr>
            </xsl:if>

            <xsl:if test="count(doc:company) > 0">
                <xsl:apply-templates select="doc:company" >
                    <xsl:sort select = "doc:name" />
                </xsl:apply-templates>
            </xsl:if>

            <xsl:call-template name="footer" />
        </table>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:header">
        <tr>
            <td>
                <table width="100%" border="0" rules="none">
                    <tr>
                        <td style="text-align:left" >
                            <table border="0" rules="none" style="font-family:Helvetica, Arial, sans-serif; font-size:{$headTextSize};">
                                <tr>
                                    <td style="text-align:center">
                                        <xsl:value-of select="doc:head1"/>
                                        <br/>
                                        <xsl:value-of select="doc:head2"/>
                                        <br/>
                                        <xsl:value-of select="doc:head3"/>
                                        <br/>
                                        <xsl:value-of select="doc:head4"/>
                                        <br/>
                                    </td>
                                </tr>
                            </table>
                        </td>
                        <td style="text-align:right">
                            <xsl:if test="doc:logo">
                                <xsl:variable name="logo">
                                    <xsl:value-of select="doc:logo" />
                                </xsl:variable>
                                <img src="{$logo}" alt=""/>
                            </xsl:if>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr>
            <td style="text-align:center; font-size: 13px; font-weight: bold">
                <p>
                    <xsl:choose>
                        <xsl:when test="/doc:examinationsAndConsultations/@contentType = 'examinations'">
                            Badania pomocnicze
                        </xsl:when>
                        <xsl:otherwise>
                            Konsultacje specjalistyczne
                        </xsl:otherwise>
                    </xsl:choose>
                    w okresie od
                    <xsl:value-of select="doc:reportDateFrom" /> do
                    <xsl:value-of select="doc:reportDateTo" />
                    <br/>
                    <xsl:value-of select="doc:text" />
                </p>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:summaryExamination">
        <tr style="text-align: center">
            <td style="text-align: center;">
                <xsl:number value="position()" format="1." />
            </td>
            <td colspan="2" >
                <xsl:value-of select="doc:description" />
            </td>
            <td>
                <xsl:value-of select="doc:count" />
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:company">
        <tr>
            <td>
                <table border="1" rules="all" width="100%" cellpadding="1" cellspacing="0"
                       style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                    <colgroup>
                        <col width="5%"/>
                        <col/>
                    </colgroup>
                    <tr style="background-color : #E6FFE6; text-align : center;">
                        <td>
                            <xsl:number value="position()" format="1." />
                        </td>
                        <td colspan="3">
                            <xsl:value-of select="doc:name" />
                            <br/>
                            <xsl:value-of select="doc:adress" />
                            <xsl:if test="count(doc:nip) > 0 or count(doc:regon) > 0">
                                <br/>
                                <xsl:if test="count(doc:nip) > 0">
                                    NIP:&#160;
                                    <xsl:value-of select="doc:nip" />
                                    &#160;
                                </xsl:if>
                                <xsl:if test="count(doc:regon) > 0">
                                    REGON:&#160;
                                    <xsl:value-of select="doc:regon" />
                                </xsl:if>
                            </xsl:if>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>

        <xsl:if test="count(doc:companySummaryExamination) = 0 and count(doc:employee) = 0">
            <tr>
                <td style="text-align: center;">
                    <font style="color: #cc0000; font-size:12px;">
                        <xsl:choose>
                            <xsl:when test="/doc:examinationsAndConsultations/@contentType = 'examinations'">
                                Nie odnaleziono badań pomocniczych w zadanym okresie.
                            </xsl:when>
                            <xsl:otherwise>
                                Nie odnaleziono konsultacji specjalistycznych w zadanym okresie.
                            </xsl:otherwise>
                        </xsl:choose>
                    </font>
                </td>
            </tr>
        </xsl:if>
        <xsl:if test="count(doc:companySummaryExamination) > 0">
            <tr>
                <td style="text-align:center; font-weight: bold; font-size:13px">
                    Zestawienie ogólne dla przedsiębiorstwa
                </td>
            </tr>
            <tr>
                <td>
                    <table border="1" rules="all" width="100%" cellpadding="1" cellspacing="0"
                           style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                        <colgroup>
                            <col width="5%"/>
                            <col width="28%"/>
                            <col width="33%"/>
                            <col/>
                        </colgroup>

                        <tr style="text-align: center; background-color: #F3F3F3;">
                            <td>
                                Lp.
                            </td>
                            <td colspan="2" >
                                <xsl:choose>
                                    <xsl:when test="/doc:examinationsAndConsultations/@contentType = 'examinations'">
                                        Nazwa badania
                                    </xsl:when>
                                    <xsl:otherwise>
                                        Nazwa konsultacji
                                    </xsl:otherwise>
                                </xsl:choose>
                            </td>
                            <td>
                                <xsl:choose>
                                    <xsl:when test="/doc:examinationsAndConsultations/@contentType = 'examinations'">
                                        Liczba wykonanych badań
                                    </xsl:when>
                                    <xsl:otherwise>
                                        Liczba wykonanych konsultacji
                                    </xsl:otherwise>
                                </xsl:choose>
                            </td>
                        </tr>

                        <xsl:apply-templates select="doc:companySummaryExamination" >
                            <xsl:with-param name="company_number" >
                                <xsl:number value="position()" format="1." />
                            </xsl:with-param>
                            <xsl:sort select = "doc:description" />
                        </xsl:apply-templates>

                    </table>
                </td>
            </tr>
        </xsl:if>
        <!-- =================================================================== -->
        <xsl:if test="count(doc:employee) > 0">
            <tr>
                <td style="text-align:center; font-weight: bold; font-size:13px">
                    Zestawienie imienne dla przedsiębiorstwa
                </td>
            </tr>
            <tr>
                <td>
                    <table border="1" rules="all" width="100%" cellpadding="1" cellspacing="0"
                           style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                        <colgroup>
                            <col width="5%"/>
                            <col width="20%"/>
                            <col width="25%"/>
                            <col width="25%"/>
                            <col/>
                        </colgroup>

                        <xsl:apply-templates select="doc:employee" >
                            <xsl:with-param name="company_number" >
                                <xsl:number value="position()" format="1." />
                            </xsl:with-param>
                            <xsl:sort select = "doc:surname" />
                            <xsl:sort select = "doc:name" />
                        </xsl:apply-templates>
                    </table>
                </td>
            </tr>
        </xsl:if>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:employee">
        <xsl:param name="company_number" />
        <tr style="background-color: #fffad5; text-align: center;">
            <td>
                <xsl:number value="$company_number" format="1." />
                <xsl:number value="position()" format="1." />
            </td>
            <td colspan="3" style="text-align: left;" >
                Nazwisko i imię:
                <xsl:value-of select="translate(doc:surname, $smallcase, $uppercase)" />&#160;
                <xsl:value-of select="translate(doc:name, $smallcase, $uppercase)" />
            </td>
            <td>
                PESEL:
                <xsl:value-of select="doc:pesel" />
            </td>
        </tr>
        <tr style="text-align: center; background-color: #F3F3F3;">
            <td colspan="2">
                <xsl:choose>
                    <xsl:when test="/doc:examinationsAndConsultations/@contentType = 'examinations'">
                        Nazwa badania
                    </xsl:when>
                    <xsl:otherwise>
                        Nazwa konsultacji
                    </xsl:otherwise>
                </xsl:choose>
            </td>
            <td>
                Data zlecenia
            </td>
            <td>
                Data wykonania
            </td>
            <td>
                Numer orzeczenia
            </td>
        </tr>
        <xsl:apply-templates select="doc:employeeDetailedExamination" >
            <xsl:sort select = "doc:performDate" />
            <xsl:sort select = "doc:decisionNo" />
        </xsl:apply-templates>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:companySummaryExamination">
        <xsl:param name="company_number" />
        <tr style="text-align: center">
            <td style="text-align: center;">
                    <xsl:number value="$company_number" format="1." />
                    <xsl:number value="position()" format="1." />
            </td>
            <td colspan="2" >
                <xsl:value-of select="doc:description" />
            </td>
            <td>
                <xsl:value-of select="doc:count" />
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:employeeDetailedExamination">
        <tr style="text-align: center">
            <td colspan="2">
                <xsl:value-of select="doc:description" />
            </td>
            <td>
                <xsl:value-of select="doc:refferalDate" />
            </td>
            <td>
                <xsl:value-of select="doc:performDate" />
            </td>
            <td>
                <xsl:value-of select="doc:decisionNo" />
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="footer">
        <tr>
            <td style="text-align: center;">
                <br/>
                Raport wygenerowany przy pomocy
            </td>
        </tr>
        <tr>
            <td  style="text-align: center;">
                <a href="http://www.softmedica.pl" target="_blank">
                    <img border="0" width="120" height="18" alt="SoftMedica Medycyna Pracy" title="SoftMedica Medycyna Pracy" src="http://www.softmedica.pl/SoftMedica120x18.png"/>
                </a>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
</xsl:stylesheet>