<?xml version="1.0" encoding="UTF-8"?>
<!--
<?xml-stylesheet type="text/xml" href="ExaminationsAndConsultations.xsl"?>
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:doc="http://softmedica.pl/schema/ExaminationsAndConsultationsUnion">
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
    <xsl:variable name="smallcase" select="'aąbcćdeęfghijklłmnńoópqrsśtuvwxyzżź'" />
    <xsl:variable name="uppercase" select="'AĄBCĆDEĘFGHIJKLŁMNŃOÓPQRSŚTUVWXYZŻŹ'" />
    <xsl:variable name="textSize">10px</xsl:variable>
    <xsl:variable name="headTextSize">10px</xsl:variable>
    <!-- =================================================================== -->
    <xsl:template match="/">
        <html>
            <head>
                <title>
                    Nieorzeczone karty badań, badania i konsultacje, w okresie dla firmy
                </title>
            </head>
            <body>
                <xsl:apply-templates select="doc:examinationsAndConsultationsUnion" />
            </body>
        </html>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:examinationsAndConsultationsUnion">
        <table border="0" rules="none" width="100%" style="font-family:Helvetica, Arial, sans-serif; font-size:11px;">
            <xsl:apply-templates select="doc:header" />
            <xsl:choose>
                <xsl:when test="count(doc:company) = 0">
                    <tr>
                        <td style="text-align: center;">
                            <font style="color: #cc0000; font-size:12px;">
                                <xsl:choose>
                                    <xsl:when test="/doc:examinationsAndConsultations/@contentType = 'examinations'">
                                        Nie odnaleziono kart badań w zadanym okresie.
                                    </xsl:when>
                                </xsl:choose>
                            </font>
                        </td>
                    </tr>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates select="doc:company" >
                        <xsl:sort select = "doc:name" />
                    </xsl:apply-templates>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:call-template name="footer" />
        </table>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:company">
        <tr>
            <td>
                <table border="1" rules="all" width="100%" cellpadding="1" cellspacing="0"
                       style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                    <tr style="background-color : #E6FFE6; text-align : center;">
                        <td>
                            <xsl:value-of select="doc:name" />
                            <br/>
                            <xsl:value-of select="doc:adress" />
                            <xsl:if test="count(doc:nip) > 0 or count(doc:regon) > 0">
                                <br/>
                                <xsl:if test="count(doc:nip) > 0">
                                    NIP:&#160;
                                    <xsl:value-of select="doc:nip" />
                                    &#160;
                                </xsl:if>
                                <xsl:if test="count(doc:regon) > 0">
                                    REGON:&#160;
                                    <xsl:value-of select="doc:regon" />
                                </xsl:if>
                            </xsl:if>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <xsl:call-template name="summary" />
        <xsl:apply-templates select="doc:examinationsAndConsultations"/>
        <xsl:apply-templates select="doc:examinationsWithoutDecisionNo"/>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="summary">
        <tr>
            <td>
                <table border="1" rules="all" width="100%" cellpadding="1" cellspacing="0"
                       style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                    <colgroup>
                        <col width="66%"/>
                        <col/>
                    </colgroup>
                    <tr>
                        <td style="text-align: left; background-color: #F3F3F3;">
                            Badan pomocniczych
                        </td>
                        <td style="text-align: center;">
                            <xsl:value-of select="count(doc:examinationsAndConsultations[@contentType = 'examinations']/doc:employee/doc:employeeDetailedExamination)" />
                        </td>
                    </tr>
                    <tr>
                        <td style="text-align: left; background-color: #F3F3F3;">
                            Konsultacji specjalistycznych
                        </td>
                        <td style="text-align: center;">
                            <xsl:value-of select="count(doc:examinationsAndConsultations[@contentType = 'consultations']/doc:employee/doc:employeeDetailedExamination)" />
                        </td>
                    </tr>
                    <tr>
                        <td style="text-align: left; background-color: #E3E3E3">
                            Razem badań
                        </td>
                        <td style="text-align: center;">
                            <xsl:value-of select="
                                          count(doc:examinationsAndConsultations[@contentType = 'examinations']/doc:employee/doc:employeeDetailedExamination) +
                                          count(doc:examinationsAndConsultations[@contentType = 'consultations']/doc:employee/doc:employeeDetailedExamination)" />
                        </td>
                    </tr>
                    <tr>
                        <td style="text-align: left; background-color: #F3F3F3;">
                            Niezakończonych badań
                        </td>
                        <td style="text-align: center;">
                            <xsl:value-of select="count(doc:examinationsWithoutDecisionNo/doc:examination)" />
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:examinationsWithoutDecisionNo">
        <xsl:if test="count(doc:examination) > 0">
            <tr>
                <td style="text-align:center; font-size: 13px; font-weight: bold">
                    <p>
                        Nieorzeczone karty badań założone w zadanym okresie
                    </p>
                </td>
            </tr>
            <tr>
                <td>
                    <table border="1" rules="all" width="100%" cellpadding="1" cellspacing="0"
                           style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                        <colgroup>
                            <col width="5%"/>
                            <col/>
                        </colgroup>
                        <tr style="text-align: center; background-color: #F3F3F3;">
                            <td>
                                Lp.
                            </td>
                            <td>
                                Nazwisko i imię
                            </td>
                            <td>
                                PESEL
                            </td>
                            <td>
                                Typ badania
                            </td>
                            <td>
                                Data badania
                            </td>
                        </tr>
                        <xsl:apply-templates select="doc:examination" >
                            <xsl:sort select = "doc:surname" />
                            <xsl:sort select = "doc:name" />
                            <xsl:sort select = "doc:examinationDate" />
                            <xsl:sort select = "doc:type" />
                        </xsl:apply-templates>
                    </table>
                </td>
            </tr>
        </xsl:if>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:examination">
        <tr style="text-align: center">
            <td>
                <xsl:number value="position()" format="1." />
            </td>
            <td>
                <xsl:value-of select="translate(doc:surname, $smallcase, $uppercase)" />&#160;
                <xsl:value-of select="translate(doc:name, $smallcase, $uppercase)" />
            </td>
            <td>
                <xsl:value-of select="doc:pesel" />
            </td>
            <td>
                <xsl:value-of select="doc:type" />
            </td>
            <td>
                <xsl:value-of select="doc:examinationDate" />
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:examinationsAndConsultations">
        <xsl:if test="count(doc:companySummaryExamination) > 0">
            <tr>
                <td style="text-align:center; font-weight: bold; font-size:13px">
                    Zestawienie ogólne
                    <xsl:choose>
                        <xsl:when test="@contentType = 'examinations'">
                            badań pomocniczych w zadanym okresie
                        </xsl:when>
                        <xsl:otherwise>
                            konsultacji specjalistycznych w zadanym okresie
                        </xsl:otherwise>
                    </xsl:choose>
                </td>
            </tr>
            <tr>
                <td>
                    <table border="1" rules="all" width="100%" cellpadding="1" cellspacing="0"
                           style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                        <colgroup>
                            <col width="5%"/>
                            <col width="28%"/>
                            <col width="33%"/>
                            <col/>
                        </colgroup>

                        <tr style="text-align: center; background-color: #F3F3F3;">
                            <td>
                                Lp.
                            </td>
                            <td colspan="2" >
                                <xsl:choose>
                                    <xsl:when test="/doc:examinationsAndConsultations/@contentType = 'examinations'">
                                        Nazwa badania
                                    </xsl:when>
                                    <xsl:otherwise>
                                        Nazwa konsultacji
                                    </xsl:otherwise>
                                </xsl:choose>
                            </td>
                            <td>
                                <xsl:choose>
                                    <xsl:when test="/doc:examinationsAndConsultations/@contentType = 'examinations'">
                                        Liczba wykonanych badań
                                    </xsl:when>
                                    <xsl:otherwise>
                                        Liczba wykonanych konsultacji
                                    </xsl:otherwise>
                                </xsl:choose>
                            </td>
                        </tr>

                        <xsl:apply-templates select="doc:companySummaryExamination" >
                            <xsl:sort select = "doc:description" />
                        </xsl:apply-templates>

                    </table>
                </td>
            </tr>
        </xsl:if>

        <xsl:if test="count(doc:employee) > 0">
            <tr>
                <td style="text-align:center; font-weight: bold; font-size:13px">
                    Zestawienie imienne
                    <xsl:choose>
                        <xsl:when test="@contentType = 'examinations'">
                            badań pomocniczych w zadanym okresie
                        </xsl:when>
                        <xsl:otherwise>
                            konsultacji specjalistycznych w zadanym okresie
                        </xsl:otherwise>
                    </xsl:choose>
                </td>
            </tr>
            <tr>
                <td>
                    <table border="1" rules="all" width="100%" cellpadding="1" cellspacing="0"
                           style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                        <colgroup>
                            <col width="5%"/>
                            <col width="20%"/>
                            <col width="25%"/>
                            <col width="25%"/>
                            <col/>
                        </colgroup>

                        <xsl:apply-templates select="doc:employee" >
                            <xsl:sort select = "doc:surname" />
                            <xsl:sort select = "doc:name" />
                        </xsl:apply-templates>
                    </table>
                </td>
            </tr>
        </xsl:if>
    </xsl:template>
    <!-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ -->
    <xsl:template match="doc:companySummaryExamination">
        <tr style="text-align: center">
            <td style="text-align: center;">
                <xsl:number value="position()" format="1." />
            </td>
            <td colspan="2" >
                <xsl:value-of select="doc:description" />
            </td>
            <td>
                <xsl:value-of select="doc:count" />
            </td>
        </tr>
    </xsl:template>
    <!-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ -->
    <xsl:template match="doc:employee">
        <tr style="background-color: #fffad5; text-align: center;">
            <td>
                <xsl:number value="position()" format="1." />
            </td>
            <td colspan="3" style="text-align: left;" >
                Nazwisko i imię:
                <xsl:value-of select="translate(doc:surname, $smallcase, $uppercase)" />&#160;
                <xsl:value-of select="translate(doc:name, $smallcase, $uppercase)" />
            </td>
            <td>
                PESEL:
                <xsl:value-of select="doc:pesel" />
            </td>
        </tr>
        <tr style="text-align: center; background-color: #F3F3F3;">
            <td colspan="2">
                <xsl:choose>
                    <xsl:when test="/doc:examinationsAndConsultations/@contentType = 'examinations'">
                        Nazwa badania
                    </xsl:when>
                    <xsl:otherwise>
                        Nazwa konsultacji
                    </xsl:otherwise>
                </xsl:choose>
            </td>
            <td>
                Data zlecenia
            </td>
            <td>
                Data wykonania
            </td>
            <td>
                Numer orzeczenia
            </td>
        </tr>
        <xsl:apply-templates select="doc:employeeDetailedExamination" >
            <xsl:sort select = "doc:performDate" />
            <xsl:sort select = "doc:decisionNo" />
        </xsl:apply-templates>
    </xsl:template>
    <!-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ -->
    <xsl:template match="doc:employeeDetailedExamination">
        <tr style="text-align: center">
            <td colspan="2">
                <xsl:value-of select="doc:description" />
            </td>
            <td>
                <xsl:value-of select="doc:refferalDate" />
            </td>
            <td>
                <xsl:value-of select="doc:performDate" />
            </td>
            <td>
                <xsl:value-of select="doc:decisionNo" />
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:header">
        <tr>
            <td>
                <table width="100%" border="0" rules="none">
                    <tr>
                        <td style="text-align:left" >
                            <table border="0" rules="none" style="font-family:Helvetica, Arial, sans-serif; font-size:{$headTextSize};">
                                <tr>
                                    <td style="text-align:center">
                                        <xsl:value-of select="doc:head1"/>
                                        <br/>
                                        <xsl:value-of select="doc:head2"/>
                                        <br/>
                                        <xsl:value-of select="doc:head3"/>
                                        <br/>
                                        <xsl:value-of select="doc:head4"/>
                                        <br/>
                                    </td>
                                </tr>
                            </table>
                        </td>
                        <td style="text-align:right">
                            <xsl:if test="doc:logo">
                                <xsl:variable name="logo">
                                    <xsl:value-of select="doc:logo" />
                                </xsl:variable>
                                <img src="{$logo}" alt=""/>
                            </xsl:if>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr>
            <td style="text-align:center; font-size: 13px; font-weight: bold">
                <p>
                    Raport dla okresu od
                    <xsl:value-of select="doc:reportDateFrom" /> do
                    <xsl:value-of select="doc:reportDateTo" />
                    <br/>
                    <xsl:value-of select="doc:text" />
                </p>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="footer">
        <tr>
            <td style="text-align: center;">
                <br/>
                Raport wygenerowany przy pomocy
            </td>
        </tr>
        <tr>
            <td  style="text-align: center;">
                <a href="http://www.softmedica.pl" target="_blank">
                    <img border="0" width="120" height="18" alt="SoftMedica Medycyna Pracy" title="SoftMedica Medycyna Pracy" src="http://www.softmedica.pl/SoftMedica120x18.png"/>
                </a>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
</xsl:stylesheet>