<?xml version="1.0" encoding="UTF-8"?>
<!--
<?xml-stylesheet type="text/xml" href="ExecutedExaminationsForPack.xsl"?>
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:doc="http://softmedica.pl/schema/ExecutedExaminationsForPack">
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
    <xsl:variable name="smallcase" select="'aąbcćdeęfghijklłmnńoópqrsśtuvwxyzżź'" />
    <xsl:variable name="uppercase" select="'AĄBCĆDEĘFGHIJKLŁMNŃOÓPQRSŚTUVWXYZŻŹ'" />
    <xsl:variable name="textSize">10px</xsl:variable>
    <xsl:variable name="headTextSize">10px</xsl:variable>
    <!-- =================================================================== -->
    <xsl:template match="/">
        <html>
            <head>
                <title>Wykonane badania</title>
            </head>
            <body>
                <xsl:apply-templates select="doc:executedExaminationsForPack" />
            </body>
        </html>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:executedExaminationsForPack">
        <table border="0" rules="none" width="100%" style="font-family:Helvetica, Arial, sans-serif; font-size:11px;">
            <xsl:apply-templates select="doc:header" />
            <xsl:if test="count(doc:company) = 0">
                <tr style="text-align: center">
                    <td>
                        <font style="color: #cc0000; font-size:12px;">
                            Nie odnaleziono badań wykonanych w zadanym okresie.
                        </font>
                    </td>
                </tr>
            </xsl:if>

            <xsl:apply-templates select="doc:company" >
                <xsl:sort select = "doc:name" />
            </xsl:apply-templates>

            <xsl:call-template name="footer" />
        </table>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:header">
        <tr>
            <td>
                <table width="100%" border="0" rules="none">
                    <tr>
                        <td style="text-align:left" >
                            <table border="0" rules="none" style="font-family:Helvetica, Arial, sans-serif; font-size:{$headTextSize};">
                                <tr>
                                    <td style="text-align:center">
                                        <xsl:value-of select="doc:head1"/>
                                        <br/>
                                        <xsl:value-of select="doc:head2"/>
                                        <br/>
                                        <xsl:value-of select="doc:head3"/>
                                        <br/>
                                        <xsl:value-of select="doc:head4"/>
                                        <br/>
                                    </td>
                                </tr>
                            </table>
                        </td>
                        <td style="text-align:right">
                            <xsl:if test="doc:logo">
                                <xsl:variable name="logo">
                                    <xsl:value-of select="doc:logo" />
                                </xsl:variable>
                                <img src="{$logo}" alt=""/>
                            </xsl:if>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr>
            <td style="text-align:center; font-size: 13px; font-weight: bold">
                <p>
                    Badania wykonane w okresie od
                    <xsl:value-of select="doc:reportDateFrom" /> do
                    <xsl:value-of select="doc:reportDateTo" />
                </p>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:company">
        <tr>
            <td>
                <table border="1" rules="all" width="100%" cellpadding="2" cellspacing="0"
                       style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                    <colgroup>
                        <col width="5%"/>
                        <col width="25%"/>
                        <col width="10%"/>
                        <col width="40%"/>
                        <col width="10%"/>
                        <col width="10%"/>
                    </colgroup>
                    <tr style="background-color : #E6FFE6; text-align : center;">
                        <td>
                            <xsl:number value="position()" format="1." />
                        </td>
                        <td colspan="5">
                            <xsl:value-of select="doc:name" />
                            <br/>
                            <xsl:value-of select="doc:adress" />
                            <xsl:if test="count(doc:nip) > 0 or count(doc:regon) > 0">
                                <br/>
                                <xsl:if test="count(doc:nip) > 0">
                                    NIP:&#160;
                                    <xsl:value-of select="doc:nip" />
                                    &#160;
                                </xsl:if>
                                <xsl:if test="count(doc:regon) > 0">
                                    REGON:&#160;
                                    <xsl:value-of select="doc:regon" />
                                </xsl:if>
                            </xsl:if>
                        </td>
                    </tr>
                    <xsl:if test="count(doc:pack) = 0">
                        <tr style="text-align: center">
                            <td colspan="6">
                                <font style="color: #cc0000">
                                    Nie odnaleziono badań wykonanych w zadanym okresie.
                                </font>
                            </td>
                        </tr>
                    </xsl:if>
                    <xsl:apply-templates select="doc:pack" >
                        <xsl:with-param name="company_number" >
                            <xsl:number value="position()" format="1." />
                        </xsl:with-param>
                        <xsl:sort select = "doc:packDescription" />
                    </xsl:apply-templates>
                </table>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:pack">
        <xsl:param name="company_number" />
        <tr style="background-color: #fffad5; text-align: center;">
            <td style="text-align: center;">
                <xsl:number value="$company_number" format="1." />
                <xsl:number value="position()" format="1." />
            </td>
            <td colspan="5" style="text-align: left;">
                Stanowisko:
                <xsl:value-of select="translate(doc:packDescription, $smallcase, $uppercase)" />
            </td>
        </tr>
        <xsl:if test="count(doc:employee) = 0">
            <tr style="text-align: center">
                <td colspan="6">
                    <font style="color: #cc0000">
                        Nie odnaleziono badań wykonanych w zadanym okresie.
                    </font>
                </td>
            </tr>
        </xsl:if>

        <tr style="background-color: #F3F3F3; text-align: center;">
            <td>
            </td>
            <td >
                Nazwisko i imię
            </td>
            <td>
                PESEL
            </td>
            <td>
                Typ badania
            </td>
            <td>
                Data badania
            </td>
            <td>
                Numer orzeczenia
            </td>
        </tr>

        <xsl:apply-templates select="doc:employee" >
            <xsl:with-param name="company_number" >
                <xsl:number value="$company_number" format="1." />
            </xsl:with-param>
            <xsl:with-param name="pack_number" >
                <xsl:number value="position()" format="1." />
            </xsl:with-param>
            <xsl:sort select = "doc:surname" />
            <xsl:sort select = "doc:name" />
        </xsl:apply-templates>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:employee">
        <xsl:param name="company_number" />
        <xsl:param name="pack_number" />
        <tr style="text-align: center;">
            <td rowspan="{count(doc:examination)}" style="text-align: center;">
                    <xsl:number value="$company_number" format="1." />
                    <xsl:number value="$pack_number" format="1." />
                    <xsl:number value="position()" format="1." />
            </td>
            <td rowspan="{count(doc:examination)}" style="text-align: left;">
                <xsl:value-of select="translate(doc:surname, $smallcase, $uppercase)" />&#160;
                <xsl:value-of select="translate(doc:name, $smallcase, $uppercase)" />
            </td>
            <td rowspan="{count(doc:examination)}">
                <xsl:value-of select="doc:pesel" />
            </td>
            <xsl:apply-templates select="doc:examination" >
                <xsl:sort select = "doc:examinationDate" />
                <xsl:sort select = "doc:decisionNo" />
            </xsl:apply-templates>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:examination">
        <xsl:if test="position() = 1">
            <xsl:call-template name="examinationItem" />
        </xsl:if>
        <xsl:if test="position() > 1">
            <tr>
                <xsl:call-template name="examinationItem" />
            </tr>
        </xsl:if>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="examinationItem">
        <td style="text-align: center;">
            <xsl:value-of select="doc:type" />
        </td>
        <td style="text-align: center;">
            <xsl:value-of select="doc:examinationDate" />
        </td>
        <td style="text-align: center;">
            <xsl:value-of select="doc:decisionNo" />
        </td>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="footer">
        <tr>
            <td style="text-align: center;">
                <br/>
                Raport wygenerowany przy pomocy
            </td>
        </tr>
        <tr>
            <td  style="text-align: center;">
                <a href="http://www.softmedica.pl" target="_blank">
                    <img border="0" width="120" height="18" alt="SoftMedica Medycyna Pracy" title="SoftMedica Medycyna Pracy" src="http://www.softmedica.pl/SoftMedica120x18.png"/>
                </a>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
</xsl:stylesheet>