<?xml version="1.0" encoding="UTF-8"?>
<!--
<?xml-stylesheet type="text/xml" href="Lumps.xsl"?>
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:doc="http://softmedica.pl/schema/Lumps">
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
    <xsl:variable name="smallcase" select="'aąbcćdeęfghijklłmnńoópqrsśtuvwxyzżź'" />
    <xsl:variable name="uppercase" select="'AĄBCĆDEĘFGHIJKLŁMNŃOÓPQRSŚTUVWXYZŻŹ'" />
    <xsl:variable name="textSize">10px</xsl:variable>
    <xsl:variable name="headTextSize">10px</xsl:variable>
    <!-- =================================================================== -->
    <xsl:template match="/">
        <html>
            <head>
                <title>Rozliczenie umowy ryczałtowej</title>
            </head>
            <body>
                <xsl:apply-templates select="doc:lumps" />
            </body>
        </html>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:lumps">
        <table border="0" rules="none" width="100%" style="font-family:Helvetica, Arial, sans-serif; font-size:11px;">
            <xsl:apply-templates select="doc:header" />
            <xsl:if test="count(doc:company) = 0">
                <tr style="text-align: center">
                    <td>
                        <font style="color: #cc0000; font-size:12px;">
                            Brak danych do rozliczenia umów ryczałtowych.
                        </font>
                    </td>
                </tr>
            </xsl:if>
            
            <xsl:apply-templates select="doc:company" >
                <xsl:sort select = "doc:name" />
            </xsl:apply-templates>
            
            <xsl:call-template name="footer" />
        </table>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:header">
        <tr>
            <td>
                <table width="100%" border="0" rules="none">
                    <tr>
                        <td style="text-align:left" >
                            <table border="0" rules="none" style="font-family:Helvetica, Arial, sans-serif; font-size:{$headTextSize};">
                                <tr>
                                    <td style="text-align:center">
                                        <xsl:value-of select="doc:head1"/>
                                        <br/>
                                        <xsl:value-of select="doc:head2"/>
                                        <br/>
                                        <xsl:value-of select="doc:head3"/>
                                        <br/>
                                        <xsl:value-of select="doc:head4"/>
                                        <br/>
                                    </td>
                                </tr>
                            </table>
                        </td>
                        <td style="text-align:right">
                            <xsl:if test="doc:logo">
                                <xsl:variable name="logo">
                                    <xsl:value-of select="doc:logo" />
                                </xsl:variable>
                                <img src="{$logo}" alt=""/>
                            </xsl:if>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr>
            <td style="text-align:center; font-size: 13px; font-weight: bold">
                <p>
                    Rozliczenie umowy ryczałtowej
                    <br/>
                    Raport na dzień
                    <xsl:value-of select="doc:reportDate" />
                </p>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:company">
        <tr>
            <td>
                <table border="1" rules="all" width="100%" cellpadding="2" cellspacing="0"
                    style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                    <colgroup>
                        <col width="5%"/>
                        <col width="70%"/>
                        <col width="25%"/>
                    </colgroup>
                    <tr style="background-color : #E6FFE6; text-align : center;">
                        <td>
                            <xsl:number value="position()" format="1." />
                        </td>
                        <td colspan="2">
                            <xsl:value-of select="doc:name" />
                            <br/>
                            <xsl:value-of select="doc:adress" />
                            <xsl:if test="count(doc:nip) > 0 or count(doc:regon) > 0">
                                <br/>
                                <xsl:if test="count(doc:nip) > 0">
                                    NIP:&#160;
                                    <xsl:value-of select="doc:nip" />
                                    &#160;
                                </xsl:if>
                                <xsl:if test="count(doc:regon) > 0">
                                    REGON:&#160;
                                    <xsl:value-of select="doc:regon" />
                                </xsl:if>
                            </xsl:if>
                        </td>
                    </tr>
                    <xsl:if test="count(doc:lump) = 0">
                        <tr style="text-align: center">
                            <td colspan="3">
                                <font style="color: #cc0000">
                                Brak danych do rozliczenia umów ryczałtowych.
                                </font>
                            </td>
                        </tr>
                    </xsl:if>
                    <xsl:apply-templates select="doc:lump" />
                </table>
            </td>
        </tr>
        <xsl:apply-templates select="doc:contract" />
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:lump">
        <tr>
            <td colspan="2" style="text-align: left">
                Liczba pracowników zatrudnionych na dzień
                <xsl:value-of select="doc:employmentRegisterDate" />
            </td>
            <td style="text-align: right">
                <xsl:value-of select="doc:employeesCount" />
            </td>
        </tr>
        <tr>
            <td colspan="2" style="text-align: left">
                Miesięczna kwota ryczałtu za pracownika
            </td>
            <td style="text-align: right">
                <xsl:value-of select="translate(doc:quotationPerEmployee, '.', ',')" /> zł
            </td>
        </tr>
        <tr>
            <td colspan="2" style="text-align: left">
                Kwota ryczałtu
            </td>
            <td style="text-align: right">
                <xsl:value-of select="translate(doc:amount, '.', ',')" /> zł
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:contract">
        <tr style="text-align: center">
            <td>Na podstawie umowy
                <xsl:if test="doc:number">
                    nr
                    <xsl:value-of select="doc:number" />,
                </xsl:if>z dnia
                <xsl:value-of select="doc:startDate" />
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="footer">
        <tr>
            <td style="text-align: center;">
                <br/>
                    Raport wygenerowany przy pomocy
            </td>
        </tr>
        <tr>
            <td  style="text-align: center;">
                <a href="http://www.softmedica.pl" target="_blank">
                    <img border="0" width="120" height="18" alt="SoftMedica Medycyna Pracy" title="SoftMedica Medycyna Pracy" src="http://www.softmedica.pl/SoftMedica120x18.png"/>
                </a>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
</xsl:stylesheet>