<?xml version="1.0" encoding="UTF-8"?>
<!--
<?xml-stylesheet type="text/xml" href="OccupationalMedicineWloclawek.xsl"?>
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:doc="http://softmedica.pl/schema/OccupationalMedicineWloclawek">
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
    <xsl:variable name="smallcase" select="'aąbcćdeęfghijklłmnńoópqrsśtuvwxyzżź'" />
    <xsl:variable name="uppercase" select="'AĄBCĆDEĘFGHIJKLŁMNŃOÓPQRSŚTUVWXYZŻŹ'" />
    <xsl:variable name="textSize">10px</xsl:variable>
    <xsl:variable name="headTextSize">10px</xsl:variable>
    <!-- =================================================================== -->
    <xsl:template match="/">
        <html>
            <head>
                <title>Ewidencja przyjęć lekarskich</title>

                <script type="text/javascript">
                    <![CDATA[

                /**
                 *
                 *  Sortable HTML table
                 *  http://www.webtoolkit.info/
                 *
                 **/

                function SortableTable (tableEl, offset) {

                    //offset - jeśli 1 nie jest sortowana pierwsza kolumna

                    this.tbody = tableEl.getElementsByTagName('tbody');
                    this.thead = tableEl.getElementsByTagName('thead');
                    this.tfoot = tableEl.getElementsByTagName('tfoot');

                    this.getInnerText = function (el) {
                        if (typeof(el.textContent) != 'undefined') return el.textContent;
                        if (typeof(el.innerText) != 'undefined') return el.innerText;
                        if (typeof(el.innerHTML) == 'string') return el.innerHTML.replace(/<[^<>]+>/g,'');
                    }

                    this.getParent = function (el, pTagName) {
                        if (el == null) return null;
                        else if (el.nodeType == 1 && el.tagName.toLowerCase() == pTagName.toLowerCase())
                            return el;
                        else
                            return this.getParent(el.parentNode, pTagName);
                    }

                    this.sort = function (cell) {

                        var column = cell.cellIndex;
                        var itm = this.getInnerText(this.tbody[0].rows[1].cells[column]);
                        var sortfn = this.sortCaseInsensitive;

                        if (itm.match(/\d\d[-]+\d\d[-]+\d\d\d\d/)) sortfn = this.sortDate; // date format mm-dd-yyyy
                        if (itm.replace(/^\s+|\s+$/g,"").match(/^[\d\.]+$/)) sortfn = this.sortNumeric;

                        this.sortColumnIndex = column;

                        var newRows = new Array();
                        for (j = 0; j < this.tbody[0].rows.length; j++) {
                            newRows[j] = this.tbody[0].rows[j];
                        }

                        newRows.sort(sortfn);

                        if (cell.getAttribute("sortdir") == 'down') {
                            newRows.reverse();
                            cell.setAttribute('sortdir','up');
                        } else {
                            cell.setAttribute('sortdir','down');
                        }

                        for (i=0;i<newRows.length;i++) {
                            this.tbody[0].appendChild(newRows[i]);
                        }

                    }

                    this.sortCaseInsensitive = function(a,b) {
                        aa = thisObject.getInnerText(a.cells[thisObject.sortColumnIndex]).toLowerCase();
                        bb = thisObject.getInnerText(b.cells[thisObject.sortColumnIndex]).toLowerCase();
                        if (aa==bb) return 0;
                        if (aa<bb) return -1;
                        return 1;
                    }

                    this.sortDate = function(a,b) {
                        aa = thisObject.getInnerText(a.cells[thisObject.sortColumnIndex]);
                        bb = thisObject.getInnerText(b.cells[thisObject.sortColumnIndex]);
                        date1 = aa.substr(6,4)+aa.substr(3,2)+aa.substr(0,2);
                        date2 = bb.substr(6,4)+bb.substr(3,2)+bb.substr(0,2);
                        if (date1==date2) return 0;
                        if (date1<date2) return -1;
                        return 1;
                    }

                    this.sortNumeric = function(a,b) {
                        aa = parseFloat(thisObject.getInnerText(a.cells[thisObject.sortColumnIndex]));
                        if (isNaN(aa)) aa = 0;
                        bb = parseFloat(thisObject.getInnerText(b.cells[thisObject.sortColumnIndex]));
                        if (isNaN(bb)) bb = 0;
                        return aa-bb;
                    }

                    // define variables
                    var thisObject = this;
                    var sortSection = this.thead;

                    // constructor actions
                    if (!(this.tbody && this.tbody[0].rows && this.tbody[0].rows.length > 0)) return;

                    if (sortSection && sortSection[0].rows && sortSection[0].rows.length > 0) {
                        var sortRow = sortSection[0].rows[0];
                    } else {
                        return;
                    }


                    for (var i=offset; i<sortRow.cells.length; i++) {
                        sortRow.cells[i].sTable = this;
                        sortRow.cells[i].onclick = function () {
                            this.sTable.sort(this);
                            setRowNumber(tableEl);
                            return false;
                        }
                    }
                }

                function setRowNumber(tableEl) {
                    var tbody = tableEl.getElementsByTagName('tbody');
                    for(rowNo=0; rowNo < tbody[0].rows.length ; rowNo++) {
                        var cell = tbody[0].rows[rowNo].cells[0] ;
                        var rowNoText = rowNo+1;
                        cell.innerHTML = rowNoText + ".";
                        cell.innerText = rowNoText + ".";
                    }
                }
                ]]>
                </script>
            </head>
            <body>
                <xsl:apply-templates select="doc:occupational_medicine_wloclawek" />
            </body>
        </html>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:occupational_medicine_wloclawek">
        <table border="0" rules="none" width="100%" style="font-family:Helvetica, Arial, sans-serif; font-size:11px;">
            <xsl:apply-templates select="doc:header" />
            <xsl:apply-templates select="doc:decider" >
                <xsl:sort select = "doc:decider_name" />
            </xsl:apply-templates>
            <xsl:call-template name="footer" />
        </table>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:decider">
        <tr>
            <td style="text-align:center; font-size: 12px;">
                Imię i nazwisko lekarza:
                <font style="font-weight: bold">
                    <xsl:value-of select="doc:decider_name"/>
                </font>
            </td>
        </tr>
        <xsl:choose>
            <xsl:when test="(count(doc:item) = 0)">
                <tr style="text-align: center">
                    <td>
                        <font style="color: #cc0000; font-size:12px;">
                            Nie odnaleziono badań wykonanych w zadanym okresie.
                        </font>
                    </td>
                </tr>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="items" />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="items">
        <tr>
            <td>
                <table id="sortable_table_{position()}" border="1" rules="all" width="100%" cellpadding="2" cellspacing="0"
                       style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                    <colgroup>
                        <col width="5%"/>
                        <col/>
                        <col width="8%"/>
                        <col width="8%"/>
                        <col width="8%"/>
                        <col width="8%"/>
                        <col width="8%"/>
                        <col width="8%"/>
                        <col width="8%"/>
                        <col width="8%"/>
                        <col width="8%"/>
                        <col width="8%"/>
                    </colgroup>
                    <thead>
                        <tr style="text-align: center; background-color: #F3F3F3;">
                            <td style="text-align: center;">
                                Lp.
                            </td>
                            <td  style="text-align: center;">
                                Data
                            </td>
                            <td  style="text-align: center;">
                                Przyjęć ogółem
                            </td>
                            <td  style="text-align: center;">
                                Badania wstępne
                            </td>
                            <td  style="text-align: center;">
                                Badania  okresowe
                            </td>
                            <td  style="text-align: center;">
                                Badania kontrolne
                            </td>
                            <td  style="text-align: center;">
                                Badania san.-epid.
                            </td>
                            <td  style="text-align: center;">
                                Kierowcy
                            </td>
                            <td  style="text-align: center;">
                                Uczniowie i studenci
                            </td>
                            <td  style="text-align: center;">
                                Licencja
                            </td>
                            <td  style="text-align: center;">
                                Kursy
                            </td>
                            <td  style="text-align: center;">
                                Inne
                            </td>
                        </tr>
                    </thead>
                    <tbody>
                        <xsl:apply-templates select="doc:item" >
                            <xsl:sort select = "doc:date" />
                        </xsl:apply-templates>
                    </tbody>
                    <tfooter>
                        <xsl:call-template name="summary" />
                    </tfooter>
                </table>

                <script type="text/javascript">
                    <!-- var t = new SortableTable(document.getElementById('sortable_table_1'), 1);  -->
                    <xsl:text>var t = new SortableTable(document.getElementById('sortable_table_</xsl:text>
                    <xsl:value-of select="position()"/>
                    <xsl:text>'), 1);</xsl:text>
                </script>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:item">
        <tr style="text-align: left">
            <td style="text-align: center;">
                <xsl:number value="position()" format="1." />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="doc:date" />
            </td>
            <td style="text-align: center; background-color: #E6FFE6">
                <xsl:value-of select="doc:count_examinations_summary" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="doc:count_primary_examinations" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="doc:count_periodical_examinations" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="doc:count_control_examinations" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="doc:count_epidemiological_examinations" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="doc:count_drivers" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="doc:count_students" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="doc:count_license" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="doc:count_course" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="doc:count_others" />
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="summary">
        <tr style="text-align: left; background-color: #E6FFE6">
            <td style="text-align: right; background-color: #F3F3F3;" colspan="2">
                Razem
            </td>
            <td style="text-align: center">
                <xsl:value-of select="sum(doc:item/doc:count_examinations_summary)" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="sum(doc:item/doc:count_primary_examinations)" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="sum(doc:item/doc:count_periodical_examinations)" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="sum(doc:item/doc:count_control_examinations)" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="sum(doc:item/doc:count_epidemiological_examinations)" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="sum(doc:item/doc:count_drivers)" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="sum(doc:item/doc:count_students)" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="sum(doc:item/doc:count_license)" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="sum(doc:item/doc:count_course)" />
            </td>
            <td style="text-align: center">
                <xsl:value-of select="sum(doc:item/doc:count_others)" />
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:header">
        <tr>
            <td>
                <table width="100%" border="0" rules="none">
                    <tr>
                        <td style="text-align:left" >
                            <table border="0" rules="none" style="font-family:Helvetica, Arial, sans-serif; font-size:{$headTextSize};">
                                <tr>
                                    <td style="text-align:center">
                                        <xsl:value-of select="doc:head1"/>
                                        <br/>
                                        <xsl:value-of select="doc:head2"/>
                                        <br/>
                                        <xsl:value-of select="doc:head3"/>
                                        <br/>
                                        <xsl:value-of select="doc:head4"/>
                                        <br/>
                                    </td>
                                </tr>
                            </table>
                        </td>
                        <td style="text-align:right">
                            <xsl:if test="doc:logo">
                                <xsl:variable name="logo">
                                    <xsl:value-of select="doc:logo" />
                                </xsl:variable>
                                <img src="{$logo}" alt=""/>
                            </xsl:if>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr>
            <td style="text-align:center; font-size: 13px; font-weight: bold">
                <p>
                    Ewidencja przyjęć lekarskich Poradni Badań Profilaktycznych
                    <br/>
                    <xsl:if test="doc:reportDateFrom != doc:reportDateTo">
                        w okresie od
                        <xsl:value-of select="doc:reportDateFrom" /> do
                        <xsl:value-of select="doc:reportDateTo" />
                    </xsl:if>
                    <xsl:if test="doc:reportDateFrom = doc:reportDateTo">
                        w dniu
                        <xsl:value-of select="doc:reportDateFrom" />
                    </xsl:if>
                </p>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="footer">
        <tr>
            <td style="text-align: center;">
                <br/>
                Raport wygenerowany przy pomocy
            </td>
        </tr>
        <tr>
            <td  style="text-align: center;">
                <a href="http://www.softmedica.pl" target="_blank">
                    <img border="0" width="120" height="18" alt="SoftMedica Medycyna Pracy" title="SoftMedica Medycyna Pracy" src="http://www.softmedica.pl/SoftMedica120x18.png"/>
                </a>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
</xsl:stylesheet>