<?xml version="1.0" encoding="UTF-8"?>
<!--
<?xml-stylesheet type="text/xml" href="ProfilacticAndEpiExaminations.xsl"?>
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:doc="http://softmedica.pl/schema/ProfilacticAndEpiExaminations">   
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
    <xsl:variable name="smallcase" select="'aąbcćdeęfghijklłmnńoópqrsśtuvwxyzżź'" />
    <xsl:variable name="uppercase" select="'AĄBCĆDEĘFGHIJKLŁMNŃOÓPQRSŚTUVWXYZŻŹ'" />
    <xsl:variable name="textSize">10px</xsl:variable>
    <xsl:variable name="headTextSize">10px</xsl:variable>
    <!-- =================================================================== -->
    <xsl:template match="/">
        <html>
            <head>
                <title>Wykonane badania profilaktyczne i do celów epi.-san.</title>
            </head>
            <body>
                <xsl:apply-templates select="doc:profilacticAndEpiExaminations" />
            </body>
        </html>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:profilacticAndEpiExaminations">
        <table border="0" rules="none" width="100%" style="font-family:Helvetica, Arial, sans-serif; font-size:11px;">
            <xsl:if test="count(doc:company) = 0 or count(doc:company/doc:employee) = 0">
                <xsl:apply-templates select="doc:header" />
                <tr style="text-align: center">
                    <td>
                        <font style="color: #cc0000; font-size:12px;">
                            Nie odnaleziono badań profilaktycznych i do celów sanitarno-epidemiologicznych, wykonanych w zadanym okresie.
                        </font>
                    </td>
                </tr>
            </xsl:if>
            <xsl:if test="count(doc:company) > 0 and count(doc:company/doc:employee) > 0">
                <xsl:apply-templates select="doc:company" >
                    <xsl:sort select = "doc:name" />
                </xsl:apply-templates>
            </xsl:if>
        </table>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:header">
        <tr>
            <td>
                <table width="100%" border="0" rules="none">
                    <tr>
                        <td style="text-align:left" >
                            <table border="0" rules="none" style="font-family:Helvetica, Arial, sans-serif; font-size:{$headTextSize};">
                                <tr>
                                    <td style="text-align:center">
                                        <xsl:value-of select="doc:head1"/>
                                        <br/>
                                        <xsl:value-of select="doc:head2"/>
                                        <br/>
                                        <xsl:value-of select="doc:head3"/>
                                        <br/>
                                        <xsl:value-of select="doc:head4"/>
                                        <br/>
                                    </td>
                                </tr>
                            </table>
                        </td>
                        <td style="text-align:right">
                            <xsl:if test="doc:logo">
                                <xsl:variable name="logo">
                                    <xsl:value-of select="doc:logo" />
                                </xsl:variable>
                                <img src="{$logo}" alt=""/>
                            </xsl:if>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr>
            <td style="text-align:center; font-size: 13px; font-weight: bold">
                <p>
                    Badania wykonane w okresie od
                    <xsl:value-of select="doc:reportDateFrom" /> do
                    <xsl:value-of select="doc:reportDateTo" />
                    <br/>
                    <xsl:value-of select="doc:text" />
                </p>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:company">
        <xsl:if test="position() > 1">
            <tr style="page-break-before: left"/>
        </xsl:if>
        <xsl:apply-templates select="../doc:header" />
        <tr>
            <td>
                <table border="1" rules="all" width="100%" cellpadding="1" cellspacing="0"
                       style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                    <colgroup>
                        <col width="5%"/>
                        <col/>
                    </colgroup>
                    <tr style="background-color : #E6FFE6; text-align : center;">
                        <td>
                            <xsl:number value="position()" format="1." />
                        </td>
                        <td>
                            <xsl:value-of select="doc:name" />
                            <br/>
                            <xsl:value-of select="doc:adress" />
                            <xsl:if test="count(doc:nip) > 0 or count(doc:regon) > 0">
                                <br/>
                                <xsl:if test="count(doc:nip) > 0">
                                    NIP:&#160;
                                    <xsl:value-of select="doc:nip" />
                                    &#160;
                                </xsl:if>
                                <xsl:if test="count(doc:regon) > 0">
                                    REGON:&#160;
                                    <xsl:value-of select="doc:regon" />
                                </xsl:if>
                            </xsl:if>
                        </td>
                    </tr>
                    <xsl:if test="doc:discount or doc:price or doc:priceWithDiscount">
                        <tr style="background-color: #E6FFE6;">
                            <td colspan="2">
                                <xsl:call-template name="examinationPrices" />
                            </td>
                        </tr>
                    </xsl:if>
                </table>
            </td>
        </tr>
        <xsl:apply-templates select="doc:employee" >
            <xsl:with-param name="company_number" >
                <xsl:number value="position()" format="1." />
            </xsl:with-param>
            <xsl:sort select = "doc:surname" />
            <xsl:sort select = "doc:name" />
        </xsl:apply-templates>
        <xsl:apply-templates select="doc:contract" />
        <xsl:call-template name="footer" />
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:contract">
        <tr style="text-align: center">
            <td>Na podstawie umowy
                <xsl:if test="doc:number">
                    nr
                    <xsl:value-of select="doc:number" />,
                </xsl:if>z dnia
                <xsl:value-of select="doc:startDate" />
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:employee">
        <xsl:param name="company_number" />
        <tr>
            <td>
                <table border="1" rules="all" width="100%" cellpadding="1" cellspacing="0"
                       style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                    <colgroup>
                        <col width="5%"/>
                        <col />
                        <col width="25%"/>
                    </colgroup>
                    <tr style="background-color: #fffad5; text-align: center;">
                        <td>
                            <xsl:number value="$company_number" format="1." />
                            <xsl:number value="position()" format="1." />
                        </td>
                        <td  style="text-align: left;">
                            Nazwisko i imię:
                            <xsl:value-of select="translate(doc:surname, $smallcase, $uppercase)" />&#160;
                            <xsl:value-of select="translate(doc:name, $smallcase, $uppercase)" />
                        </td>
                        <td>
                            PESEL:
                            <xsl:value-of select="doc:pesel" />
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <xsl:apply-templates select="doc:examination" >
            <xsl:with-param name="employee_number" >
                <xsl:number value="$company_number" format="1." />
                <xsl:number value="position()" format="1." />
            </xsl:with-param>
            <xsl:sort select = "doc:examinationDate" />
            <xsl:sort select = "doc:decisionNo" />
        </xsl:apply-templates>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:examination">
        <xsl:param name="employee_number" />
        <tr>
            <td>
                <table border="1" rules="all" width="100%" cellpadding="1" cellspacing="0"
                       style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
                    <colgroup>
                        <col width="5%"/>
                        <col width="25%"/>
                        <col width="20%"/>
                        <col width="25%"/>
                        <col width="25%"/>
                    </colgroup>
                    <tr style="text-align: center; background-color: #e4f1ff">
                        <td>
                            <xsl:value-of select="$employee_number" />
                            <xsl:number value="position()" format="1." />
                        </td>
                        <xsl:choose>
                            <xsl:when test="doc:type_code = '4'">
                                <td colspan="2">
                                    Typ badania:
                                    <xsl:value-of select="doc:type" />
                                </td>
                            </xsl:when>
                            <xsl:otherwise>
                                <td>
                                    Typ badania:
                                    <xsl:value-of select="doc:type" />
                                </td>
                                <td>
                                    Stanowisko:
                                    <xsl:value-of select="doc:workplace" />
                                </td>
                            </xsl:otherwise>
                        </xsl:choose>

                        <td>
                            Data badania:
                            <xsl:value-of select="doc:examinationDate" />
                        </td>
                        <td>
                            Numer orzeczenia:
                            <xsl:value-of select="doc:decisionNo" />
                        </td>
                    </tr>
                    <xsl:if test="doc:priceForWorklplace or doc:priceForPack or doc:discount or doc:price or doc:priceWithDiscount">
                        <tr style="background-color: #e4f1ff">
                            <td colspan="5">
                                <xsl:call-template name="examinationPrices" />
                            </td>
                        </tr>
                    </xsl:if>
                    <xsl:if test="count(doc:examinationsAndConsultations) > 0">
                        <tr>
                            <xsl:choose>
                                <xsl:when test="doc:type_code = '4'">
                                    <td colspan="5" style="vertical-align: top; padding: 0px">
                                        <xsl:call-template name="auxiliaryExaminations" />
                                    </td>
                                </xsl:when>
                                <xsl:otherwise>
                                    <td colspan="3" style="vertical-align: top; padding: 0px">
                                        <xsl:call-template name="auxiliaryExaminations" />
                                    </td>
                                    <td colspan="2" style="vertical-align: top; padding: 0px">
                                        <xsl:call-template name="specialisticConsultations" />
                                    </td>
                                </xsl:otherwise>
                            </xsl:choose>
                        </tr>
                        <xsl:if test="doc:type_type != '4' and count(doc:examinationsAndConsultations[@type = 'extendedExamination']) > 0">
                            <tr >
                                <td colspan="3" style="vertical-align: top; padding: 0px">
                                    <xsl:call-template name="extendedExaminations" />
                                </td>
                                <td colspan="2">

                                </td>
                            </tr>
                        </xsl:if>
                    </xsl:if>
                    <!--xsl:if test="doc:priceForWorklplace or doc:priceForPack or doc:discount or doc:price or doc:priceWithDiscount">
                        <tr style="background-color: #e4f1ff">
                            <td colspan="5">
                                <xsl:call-template name="examinationPrices" />
                            </td>
                        </tr>
                    </xsl:if-->
                </table>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="examinationPrices">
        <table border="0" rules="none" width="40%" cellpadding="1" cellspacing="0"
               style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize}; ">
            <colgroup>
                <col width="75%"/>
                <col width="20%"/>
                <col/>
            </colgroup>
            <xsl:if test="doc:priceForWorklplace">
                <tr>
                    <td>
                        Należność za badania stanowiskowe
                    </td>
                    <td style="text-align: right">
                        <xsl:value-of select="translate(doc:priceForWorklplace, '.', ',')" />
                    </td>
                    <td>
                        zł
                    </td>
                </tr>
            </xsl:if>

            <xsl:if test="doc:priceForPack">
                <tr >
                    <td>
                        Należność za badania pakietowe
                    </td>
                    <td style="text-align: right">
                        <xsl:value-of select="translate(doc:priceForPack, '.', ',')" />
                    </td>
                    <td>
                        zł
                    </td>
                </tr>
            </xsl:if>

            <xsl:if test="doc:price">
                <tr >
                    <td>
                        Należność
                    </td>
                    <td style="text-align: right">
                        <xsl:value-of select="translate(doc:price, '.', ',')" />
                    </td>
                    <td>
                        zł
                    </td>
                </tr>
            </xsl:if>

            <xsl:if test="doc:discount">
                <tr >
                    <td>
                        Rabat
                    </td>
                    <td style="text-align: right">
                        <xsl:value-of select="doc:discount" />
                    </td>
                    <td>
                        %
                    </td>
                </tr>
            </xsl:if>

            <xsl:if test="doc:priceWithDiscount">
                <tr >
                    <td>
                        Należność z rabatem
                    </td>
                    <td style="text-align: right">
                        <xsl:value-of select="translate(doc:priceWithDiscount, '.', ',')" />
                    </td>
                    <td>
                        zł
                    </td>
                </tr>
            </xsl:if>

            <xsl:if test="../doc:company">
                <tr >
                    <td>
                        Liczba kart badań
                    </td>
                    <td style="text-align: right">
                        <xsl:value-of select="count(doc:employee/doc:examination)" />
                    </td>
                    <td>
                        szt.
                    </td>
                </tr>
            </xsl:if>

        </table>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:examinationsAndConsultations">
        <tr style="text-align: center">
            <td style="text-align: left">
                <xsl:value-of select="doc:description" />
            </td>
            <xsl:if test="@type != 'extendedExamination'">
                <td>
                    <xsl:value-of select="doc:refferalDate" />
                </td>
                <td>
                    <xsl:value-of select="doc:performDate" />
                </td>
            </xsl:if>
            <xsl:if test="count(doc:price) > 0">
                <td>
                    <xsl:value-of select="translate(doc:price, '.', ',')" /> zł
                </td>
            </xsl:if>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="footer">
        <tr>
            <td style="text-align: center;">
                <br/>
                Raport wygenerowany przy pomocy
            </td>
        </tr>
        <tr>
            <td  style="text-align: center;">
                <a href="http://www.softmedica.pl" target="_blank">
                    <img border="0" width="120" height="18" alt="SoftMedica Medycyna Pracy" title="SoftMedica Medycyna Pracy" src="http://www.softmedica.pl/SoftMedica120x18.png"/>
                </a>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="auxiliaryExaminations">
        <table border="1" rules="rows" frame="void" width="100%" cellpadding="1" cellspacing="0"
               style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
            <colgroup>
                <col/>
                <col width="20%"/>
                <col width="20%"/>
                <xsl:if test="count(doc:examinationsAndConsultations/doc:price) > 0">
                    <col width="20%"/>
                </xsl:if>
            </colgroup>

            <tr style="text-align: center; background-color: #E3E3E3;">
                <xsl:if test="count(doc:examinationsAndConsultations/doc:price) = 0">
                    <td colspan="3">
                        <xsl:choose>
                            <xsl:when test="doc:type_code != '4'">
                                Badania pomocnicze
                            </xsl:when>
                            <xsl:otherwise>
                                Badania pomocnicze i konsultacje specjalistyczne
                            </xsl:otherwise>
                        </xsl:choose>
                    </td>
                </xsl:if>

                <xsl:if test="count(doc:examinationsAndConsultations/doc:price) > 0">
                    <td colspan="4">
                        <xsl:choose>
                            <xsl:when test="doc:type_code != '4'">
                                Badania pomocnicze
                            </xsl:when>
                            <xsl:otherwise>
                                Badania pomocnicze i konsultacje specjalistyczne
                            </xsl:otherwise>
                        </xsl:choose>
                    </td>
                </xsl:if>
            </tr>

            <xsl:if test="doc:examinationsAndConsultations/@type = 'auxiliaryExamination'">
                <xsl:call-template name="auxiliaryExaminationsHeader"/>
            </xsl:if>
            <xsl:apply-templates select="doc:examinationsAndConsultations[@type = 'auxiliaryExamination']"/>
        </table>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="specialisticConsultations">
        <table border="1" rules="rows" frame="void" width="100%" cellpadding="1" cellspacing="0"
               style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
            <colgroup>
                <col/>
                <col width="20%"/>
                <col width="20%"/>
                <xsl:if test="count(doc:examinationsAndConsultations/doc:price) > 0">
                    <col width="20%"/>
                </xsl:if>
            </colgroup>

            <tr style="text-align: center; background-color: #E3E3E3;">
                <xsl:if test="count(doc:examinationsAndConsultations/doc:price) = 0">
                    <td colspan="3">
                        Konsultacje specjalistyczne
                    </td>
                </xsl:if>

                <xsl:if test="count(doc:examinationsAndConsultations/doc:price) > 0">
                    <td colspan="4">
                        Konsultacje specjalistyczne
                    </td>
                </xsl:if>
            </tr>

            <xsl:if test="doc:examinationsAndConsultations/@type = 'specialisticConsultation'">
                <xsl:call-template name="auxiliaryExaminationsHeader"/>
            </xsl:if>
            <xsl:apply-templates select="doc:examinationsAndConsultations[@type = 'specialisticConsultation']"/>
        </table>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="auxiliaryExaminationsHeader">
        <tr style="text-align: center; background-color: #F3F3F3;">
            <td>
                Nazwa
            </td>
            <td>
                Data zlecenia
            </td>
            <td>
                Data wykonania
            </td>
            <xsl:if test="count(doc:examinationsAndConsultations/doc:price) > 0">
                <td>
                    Cena
                </td>
            </xsl:if>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="extendedExaminations">
        <table border="1" rules="rows" frame="void" width="100%" cellpadding="1" cellspacing="0"
               style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">
            <colgroup>
                <col/>
                <xsl:if test="count(doc:examinationsAndConsultations/doc:price) > 0">
                    <col width="20%"/>
                </xsl:if>
            </colgroup>

            <tr style="text-align: center; background-color: #E3E3E3;">
                <xsl:if test="count(doc:examinationsAndConsultations/doc:price) = 0">
                    <td>
                        Badania poszerzone
                    </td>
                </xsl:if>

                <xsl:if test="count(doc:examinationsAndConsultations/doc:price) > 0">
                    <td colspan="2">
                        Badania poszerzone
                    </td>
                </xsl:if>
            </tr>

            <xsl:if test="doc:examinationsAndConsultations/@type = 'extendedExamination'">
                <xsl:call-template name="extendedExaminationsHeader"/>
            </xsl:if>
            <xsl:apply-templates select="doc:examinationsAndConsultations[@type = 'extendedExamination']"/>
        </table>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="extendedExaminationsHeader">
        <tr style="text-align: center; background-color: #F3F3F3;">
            <td>
                Nazwa
            </td>
            <xsl:if test="count(doc:examinationsAndConsultations/doc:price) > 0">
                <td>
                    Cena
                </td>
            </xsl:if>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
</xsl:stylesheet>