<?xml version="1.0" encoding="UTF-8"?>
<!-- REFERENCYJNY ARKUSZ STYLÓW -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0" xmlns:doc="http://softmedica.pl/schema/Raport">
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
    <xsl:variable name="smallcase" select="'aąbcćdeęfghijklłmnńoópqrsśtuvwxyzżź'" />
    <xsl:variable name="uppercase" select="'AĄBCĆDEĘFGHIJKLŁMNŃOÓPQRSŚTUVWXYZŻŹ'" />
    <xsl:variable name="textSize">10px</xsl:variable>
    <xsl:variable name="headTextSize">10px</xsl:variable>
    <!-- =================================================================== -->
    <xsl:template match="/">
        <xsl:text disable-output-escaping='yes'><![CDATA[<!DOCTYPE html>]]>
        </xsl:text>
        <html>
            <head>
                <style>
                    <![CDATA[
                    <!--
                    .initial {background-color: #FFFFFF; color:#000000}
                    .normal {background-color: #FFFFFF}
                    .highlight {background-color: #FFFFCC}
                    -->
                    ]]>
                </style>            
                <title>
                    <xsl:value-of select="doc:raport/doc:naglowek/doc:nazwa"/>
                </title>
                <script type="text/javascript">
                    <![CDATA[
                    /**
                     *
                     *  Sortable HTML table
                     *  http://www.webtoolkit.info/
                     *
                     **/

                    function SortableTable (tableEl, offset) {

                        //offset - jeśli 1 nie jest sortowana pierwsza kolumna

                        this.tbody = tableEl.getElementsByTagName('tbody');
                        this.thead = tableEl.getElementsByTagName('thead');
                        this.tfoot = tableEl.getElementsByTagName('tfoot');

                        this.getInnerText = function (el) {
                            if (typeof(el.textContent) != 'undefined') return el.textContent;
                            if (typeof(el.innerText) != 'undefined') return el.innerText;
                            if (typeof(el.innerHTML) == 'string') return el.innerHTML.replace(/<[^<>]+>/g,'');
                        }

                        this.getParent = function (el, pTagName) {
                            if (el == null) return null;
                            else if (el.nodeType == 1 && el.tagName.toLowerCase() == pTagName.toLowerCase())
                                return el;
                            else
                                return this.getParent(el.parentNode, pTagName);
                        }

                        this.sort = function (cell) {

                            var column = cell.cellIndex;
                            var itm = this.getInnerText(this.tbody[0].rows[1].cells[column]);
                            var sortfn = this.sortCaseInsensitive;

                            if (itm.match(/\d\d[-]+\d\d[-]+\d\d\d\d/)) sortfn = this.sortDate; // date format mm-dd-yyyy
                            if (itm.replace(/^\s+|\s+$/g,"").match(/^[\d\.]+$/)) sortfn = this.sortNumeric;

                            this.sortColumnIndex = column;

                            var newRows = new Array();
                            for (j = 0; j < this.tbody[0].rows.length; j++) {
                                newRows[j] = this.tbody[0].rows[j];
                            }

                            newRows.sort(sortfn);

                            if (cell.getAttribute("sortdir") == 'down') {
                                newRows.reverse();
                                cell.setAttribute('sortdir','up');
                            } else {
                                cell.setAttribute('sortdir','down');
                            }

                            for (i=0;i<newRows.length;i++) {
                                this.tbody[0].appendChild(newRows[i]);
                            }

                        }

                        this.sortCaseInsensitive = function(a,b) {
                            aa = thisObject.getInnerText(a.cells[thisObject.sortColumnIndex]).toLowerCase();
                            bb = thisObject.getInnerText(b.cells[thisObject.sortColumnIndex]).toLowerCase();
                            if (aa==bb) return 0;
                            if (aa<bb) return -1;
                            return 1;
                        }

                        this.sortDate = function(a,b) {
                            aa = thisObject.getInnerText(a.cells[thisObject.sortColumnIndex]);
                            bb = thisObject.getInnerText(b.cells[thisObject.sortColumnIndex]);
                            date1 = aa.substr(6,4)+aa.substr(3,2)+aa.substr(0,2);
                            date2 = bb.substr(6,4)+bb.substr(3,2)+bb.substr(0,2);
                            if (date1==date2) return 0;
                            if (date1<date2) return -1;
                            return 1;
                        }

                        this.sortNumeric = function(a,b) {
                            aa = parseFloat(thisObject.getInnerText(a.cells[thisObject.sortColumnIndex]));
                            if (isNaN(aa)) aa = 0;
                            bb = parseFloat(thisObject.getInnerText(b.cells[thisObject.sortColumnIndex]));
                            if (isNaN(bb)) bb = 0;
                            return aa-bb;
                        }

                        // define variables
                        var thisObject = this;
                        var sortSection = this.thead;

                        // constructor actions
                        if (!(this.tbody && this.tbody[0].rows && this.tbody[0].rows.length > 0)) return;

                        if (sortSection && sortSection[0].rows && sortSection[0].rows.length > 0) {
                            var sortRow = sortSection[0].rows[0];
                        } else {
                            return;
                        }

                        for (var i=offset; i<sortRow.cells.length; i++) {
                            sortRow.cells[i].sTable = this;
                            sortRow.cells[i].onclick = function () {
                                this.sTable.sort(this);
                                if(offset>0) {
                                    setRowNumber(tableEl);                                
                                }
                                return false;
                            }
                        }
                    }

                    function setRowNumber(tableEl) {
                        var tbody = tableEl.getElementsByTagName('tbody');
                        for(rowNo=0; rowNo < tbody[0].rows.length ; rowNo++) {
                            var cell = tbody[0].rows[rowNo].cells[0] ;
                            var rowNoText = rowNo+1;
                            cell.innerHTML = rowNoText + ".";
                            cell.innerText = rowNoText + ".";
                        }
                    }
                    ]]>
                </script>
            </head>
            <body>
                <xsl:apply-templates select="doc:raport" />
            </body>
        </html>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:naglowek">
        <tr>
            <td>
                <table width="100%" border="0" rules="none">
                    <tr>
                        <td style="text-align:left" >
                            <table border="0" rules="none" style="font-family:Helvetica, Arial, sans-serif; font-size:{$headTextSize};">
                                <tr>
                                    <td style="text-align:center">
                                        <xsl:value-of select="doc:naglowek1"/>
                                        <br/>
                                        <xsl:value-of select="doc:naglowek2"/>
                                        <br/>
                                        <xsl:value-of select="doc:naglowek3"/>
                                        <br/>
                                        <xsl:value-of select="doc:naglowek4"/>
                                        <br/>
                                    </td>
                                </tr>
                            </table>
                        </td>
                        <td style="text-align:right">
                            <xsl:if test="doc:logo">
                                <xsl:variable name="logo">
                                    <xsl:value-of select="doc:logo" />
                                </xsl:variable>
                                <img src="{$logo}" alt=""/>
                            </xsl:if>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr>
            <td style="text-align:center; font-size: 13px; font-weight: bold">
                <p>
                    <xsl:value-of select="doc:tytul" disable-output-escaping="yes"/>
                </p>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template name="stopka">
        <tr>
            <td style="text-align: center;">
                <br/>
                Raport wygenerowany przy pomocy
            </td>
        </tr>
        <tr>
            <td  style="text-align: center;">
                <a href="http://www.softmedica.pl" target="_blank">
                    <img border="0" width="120" height="18" alt="SoftMedica Medycyna Pracy" title="SoftMedica Medycyna Pracy" src="http://www.softmedica.pl/SoftMedica120x18.png"/>
                </a>
            </td>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:raport">
        <table border="0" rules="none" width="100%" style="font-family:Helvetica, Arial, sans-serif; font-size:11px;">
            <xsl:apply-templates select="doc:naglowek" />

            <xsl:if test="count(doc:tabela/doc:wiersz) = 0">
                <tr style="text-align: center">
                    <td>
                        <font style="color: #cc0000; font-size:12px;">
                            Nie odnaleziono danych spełniających zadane kryteria.
                        </font>
                    </td>
                </tr>
            </xsl:if>

            <xsl:apply-templates select="doc:tabela"/>

            <xsl:call-template name="stopka" />
        </table>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:naglowek" mode="naglowek_tabeli">           
        <tr style="text-align: center; background-color: #F3F3F3;">             
            <xsl:if test="../doc:numeracja_wierszy = 'true'">
                <xsl:variable name="pozycja">                                    
                    <xsl:value-of select="position()" />                                
                </xsl:variable>
                <xsl:if test="$pozycja = 1">
                    <xsl:variable name="rowspan">                                    
                        <xsl:value-of select="count(../doc:naglowek)" />                                
                    </xsl:variable>
                    <td rowspan="{$rowspan}">
                        Lp.
                    </td>     
                </xsl:if>
            </xsl:if>
            <xsl:apply-templates select="doc:komorka" mode="naglowek_tabeli"/>
        </tr>        
    </xsl:template>
    
    <xsl:template match="doc:komorka" mode="naglowek_tabeli">
        <xsl:variable name="colspan">
            <xsl:choose>
                <xsl:when test="@liczba_kolumn">                
                    <xsl:value-of select="@liczba_kolumn" />
                </xsl:when>                                    
                <xsl:otherwise>
                    <xsl:value-of select="1" />
                </xsl:otherwise>                        
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="rowspan">
            <xsl:choose>
                <xsl:when test="@liczba_wierszy">                
                    <xsl:value-of select="@liczba_wierszy" />
                </xsl:when>                                    
                <xsl:otherwise>
                    <xsl:value-of select="1" />
                </xsl:otherwise>                         
            </xsl:choose>
        </xsl:variable>
        <td colspan="{$colspan}" rowspan="{$rowspan}">
            <xsl:value-of select="." />
        </td>
    </xsl:template>
    
    <xsl:template match="doc:komorka" mode="szerokosc_kolumny">        
        <xsl:choose>
            <xsl:when test="@szerokosc != '-1'">
                <xsl:variable name="width">
                    <xsl:value-of select="@szerokosc" />
                </xsl:variable>
                <col width="{@szerokosc}"/>
            </xsl:when>                                    
            <xsl:otherwise>
                <col/>
            </xsl:otherwise>
        </xsl:choose>        
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:podsumowanie" mode="podsumowanie_tabeli">        
        <tr style="text-align: center; background-color: #F3F3F3;">                
            <xsl:apply-templates select="doc:komorka" mode="podsumowanie_tabeli"/>
        </tr>        
    </xsl:template>
    
    <xsl:template match="doc:komorka" mode="podsumowanie_tabeli">
               
        <xsl:variable name="colspan">
            <xsl:choose>
                <xsl:when test="@liczba_kolumn">
                    <xsl:choose>
                        <xsl:when test="@id=0 and ../../doc:numeracja_wierszy = 'true'">
                            <xsl:value-of select="@liczba_kolumn+1" />
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="@liczba_kolumn" />
                        </xsl:otherwise>     
                    </xsl:choose>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:choose>
                        <xsl:when test="@id=0 and ../../doc:numeracja_wierszy = 'true'">
                            <xsl:value-of select="2" />
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="1" />
                        </xsl:otherwise>   
                    </xsl:choose>
                </xsl:otherwise>
            </xsl:choose>                
        </xsl:variable>
        
        <xsl:variable name="style">
            <xsl:choose>
                <xsl:when test="@oblicz">
                    <xsl:text>background-color: #E6FFE6;</xsl:text>
                </xsl:when>                
            </xsl:choose>                
        </xsl:variable>
               
        <td colspan="{$colspan}" style="{$style}">
            <xsl:choose>
                <xsl:when test="@oblicz">
                    <xsl:variable name="id_kolumny">
                        <xsl:value-of select="@oblicz" />      
                    </xsl:variable>
                    <xsl:value-of select="sum(../../doc:wiersz/doc:komorka[@id=$id_kolumny])"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="." />                                        
                </xsl:otherwise>
            </xsl:choose>            
        </td>                        
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:tabela">
        <xsl:if test="count(doc:tytul) > 0">
            <tr>
                <td style="text-align:center; font-size: 13px; font-weight: bold">
                    <p>
                        <xsl:value-of select="doc:tytul" disable-output-escaping="yes"/>
                    </p>
                </td>
            </tr>
        </xsl:if>

        <xsl:if test="count(doc:wiersz) > 0">
            <tr>
                <td>
                    <table id="sortable_table_{@id}" border="1" rules="all" width="100%" cellpadding="2" cellspacing="0"
                           style="border-color: #E3E3E3; font-family:Helvetica, Arial, sans-serif; font-size:{$textSize};">                         
                        <colgroup>       
                            <xsl:if test="doc:numeracja_wierszy = 'true'">
                                <col width="3%"/>                        
                            </xsl:if>
                            <xsl:apply-templates select="doc:naglowek/doc:komorka" mode="szerokosc_kolumny"/>
                        </colgroup>   
                        <thead>                            
                            <xsl:apply-templates select="doc:naglowek" mode="naglowek_tabeli"/>
                        </thead>   
                        <tbody>
                            <xsl:apply-templates select="doc:wiersz"/>
                        </tbody>
                        <tfoot>
                            <xsl:apply-templates select="doc:podsumowanie" mode="podsumowanie_tabeli"/>
                        </tfoot>
                    </table>
                    
                    <xsl:if test="doc:sortowanie_wierszy = 'true'">
                        <script type="text/javascript">
                            <xsl:text>var t = new SortableTable(document.getElementById('sortable_table_</xsl:text>
                            <xsl:value-of select="@id"/>
                            <xsl:text>'),</xsl:text> 
                            <xsl:choose>
                                <xsl:when test="doc:numeracja_wierszy = 'true'">                                
                                    <xsl:value-of select="1" />                                
                                </xsl:when>                                    
                                <xsl:otherwise>
                                    <xsl:value-of select="0" />       
                                </xsl:otherwise>
                            </xsl:choose>   
                            <xsl:text>);</xsl:text>
                        </script>
                    </xsl:if>
                </td>
            </tr>
        </xsl:if>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:wiersz">
        <tr onMouseOver="this.className='highlight'" onMouseOut="this.className='normal'">  
            <xsl:if test="../doc:numeracja_wierszy = 'true'">
                <td style="text-align: center;">
                    <xsl:number value="position()" format="1." />
                </td>            
            </xsl:if>
            <xsl:apply-templates select="doc:komorka"/>
        </tr>
    </xsl:template>
    <!-- =================================================================== -->
    <xsl:template match="doc:komorka">
        
        <xsl:variable name="id_komorki">
            <xsl:value-of select="@id" />
        </xsl:variable>        
        
        <xsl:variable name="wyrownanie">
            <xsl:value-of select="../../doc:naglowek[1]/doc:komorka[@id=$id_komorki]/@wyrownanie" />
        </xsl:variable>              
       
        <xsl:choose>
            <xsl:when test="$wyrownanie != ''">                                
                <td style="text-align: {$wyrownanie}">
                    <xsl:call-template name="replace">
                        <xsl:with-param name="string" select="."/>
                    </xsl:call-template>
                </td>                      
            </xsl:when>                                    
            <xsl:otherwise>
                <td style="text-align: center">
                    <xsl:call-template name="replace">
                        <xsl:with-param name="string" select="."/>
                    </xsl:call-template>
                </td>    
            </xsl:otherwise>
        </xsl:choose>        
    </xsl:template>
    <!-- wstawianie znacznika nowej linii -->
    <xsl:template name="replace">
        <xsl:param name="string"/>
        <xsl:choose>
            <xsl:when test="contains($string,'&#10;')">
                <xsl:value-of select="substring-before($string,'&#10;')"/>
                <br/>
                <xsl:call-template name="replace">
                    <xsl:with-param name="string"  select="substring-after($string,'&#10;')"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$string"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- =================================================================== -->
</xsl:stylesheet>
